package com.mints.goodmoney;

import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;
import android.webkit.WebView;

import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.multidex.MultiDexApplication;

import com.hjq.toast.ToastUtils;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.manager.ChannelManager;
import com.mints.goodmoney.manager.LiebaoManager;
import com.mints.goodmoney.manager.MhManager;
import com.mints.goodmoney.manager.MiitHelper;
import com.mints.goodmoney.manager.RsNewsManager;
import com.mints.goodmoney.manager.TtCsjAdManager;
import com.mints.goodmoney.manager.TzManager;
import com.mints.goodmoney.manager.WnManager;
import com.mints.goodmoney.manager.YlVideoManager;
import com.mints.goodmoney.manager.YlhAdManager;
import com.mints.goodmoney.net.LoanService;
import com.mints.goodmoney.utils.ForegroundOrBackground;
import com.mints.goodmoney.utils.LogUtil;
import com.mints.goodmoney.utils.SystemUtils;
import com.mints.library.utils.CommonUtils;
import com.orhanobut.logger.AndroidLogAdapter;
import com.orhanobut.logger.FormatStrategy;
import com.orhanobut.logger.Logger;
import com.orhanobut.logger.PrettyFormatStrategy;
import com.tendcloud.tenddata.TCAgent;
import com.umeng.analytics.MobclickAgent;
import com.umeng.commonsdk.UMConfigure;
import com.ximalaya.ting.android.opensdk.constants.ConstantsOpenSdk;
import com.ximalaya.ting.android.opensdk.datatrasfer.CommonRequest;
import com.ximalaya.ting.android.opensdk.player.service.XmPlayerConfig;
import com.ximalaya.ting.android.opensdk.util.BaseUtil;

import java.util.concurrent.Executors;

import rx.Scheduler;
import rx.schedulers.Schedulers;

/**
 * 描述：Application
 * 作者：孟崔广
 * 时间：2020/10/09 11:40
 */
public class MintsApplication extends MultiDexApplication {

    private static MintsApplication mContext;
    public static String OAID = "";

    private static LocalBroadcastManager mLocalBroadcastManager;
    private Scheduler defaultSubscribeScheduler;

    private LoanService loanService;

    public static MintsApplication getContext() {
        return mContext;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        mContext = this;
        // 判断应用是否在前台
        ForegroundOrBackground.init(this);

        // 三方配置
        thirdConfig();
    }

    private void androidPWebView() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            String processName = getProcessName(this);
            String packageName = this.getPackageName();
            if (!packageName.equals(processName)) {
                try {
                    // 为不同进程webView设置不同目录
                    WebView.setDataDirectorySuffix("dds_" + processName);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    @Override
    public void onLowMemory() {
        android.os.Process.killProcess(android.os.Process.myPid());
        super.onLowMemory();
    }

    @Override
    protected void attachBaseContext(Context base) {
        super.attachBaseContext(base);

        // 9.0之后不可多进程使用一个目录下的WebView，写在SDK初始化之前
        androidPWebView();
    }

    /*
     * 三方配置
     */
    private void thirdConfig() {
        // 初始化toast
        initToast();

        // 移动安全联盟 oaid
        initMiitHelper();

        // 按渠道匹配代码位
        ChannelManager.INSTANCE.updataCodeIdForRegisterChannel(null);

        // 优量汇
        YlhAdManager.INSTANCE.initYlhAd(this);

        // 穿山甲
        TtCsjAdManager.init(this);

        // 闪电盒子
        WnManager.INSTANCE.initWn(this);

        // 枫岚广告
        MhManager.INSTANCE.initWn(this);

        // 一览视频
        YlVideoManager.INSTANCE.init(this);

        // 猎豹游戏初始化
        LiebaoManager.getInstance().initCmGameSdk();

        // 瑞狮新闻
        RsNewsManager.INSTANCE.initX5Environment(this);

        // 喜马拉雅
        initXmly();

        // 自定义logger
        bindLogger();

        // 天卓珊瑚
        TzManager.INSTANCE.initTz(this);

        // 子线程初始化三方SDK
        String processName = SystemUtils.INSTANCE.getProcessName(this, android.os.Process.myPid());
        if (processName != null) {
            // 判断onCreate方法执行是否在当前应用的application上
            boolean defaultProcess = TextUtils.equals(processName, Constant.MINTS_PKG_NAME);
            if (defaultProcess) {
                InitAppService.Companion.start(this); //初始化数据
            }
        }
    }

    /**
     * 初始化喜马拉雅
     */
    private void initXmly() {
        XmPlayerConfig.getInstance(this).setDefualtNotificationNickNameAndInfo(Constant.MINTS_APP_NAME, Constant.MINTS_APP_NAME);
        if (BaseUtil.isMainProcess(this)) {
            ConstantsOpenSdk.isDebug = BuildConfig.DEBUG;
            CommonRequest mXimalaya = CommonRequest.getInstanse();
            String mAppSecret = "db3cb9e3ec5943f4987e78ddc5aec728";
            String mAppKey = "ff71a11162f20808f9f349452dd9e141";
            mXimalaya.setAppkey(mAppKey);
            mXimalaya.setPackid(Constant.MINTS_PKG_NAME);
            mXimalaya.init(this, mAppSecret);
        }
    }

    /**
     * 自定义logger
     */
    private void bindLogger() {
        //自定义logger
        FormatStrategy formatStrategy = PrettyFormatStrategy.newBuilder()
                .showThreadInfo(false)  //是否选择显示线程信息，默认为true
                .methodCount(0)         //方法数显示多少行，默认2行
                .methodOffset(7)        //隐藏方法内部调用到偏移量，默认5
                // .logStrategy(customLog) //打印日志的策略，默认LogCat
                .tag("mints---network")   //自定义TAG全部标签，默认PRETTY_LOGGER
                .build();
        Logger.addLogAdapter(new AndroidLogAdapter(formatStrategy));
    }

    private MiitHelper.AppIdsUpdater appIdsUpdater = ids -> OAID = ids;

    /**
     * 移动安装联盟 获取OAID等设备标识符
     */
    private void initMiitHelper() {
        try {
            MiitHelper miitHelper = new MiitHelper(appIdsUpdater);
            miitHelper.initDeviceIds(getApplicationContext());
        } catch (Exception e) {
            e.printStackTrace();
            LogUtil.e(e);
        }
    }

    /**
     * 设置TalkingData
     */
    public void TalkingDataConfig() {
        try {
            TCAgent.LOG_ON = BuildConfig.DEBUG;
            String talkingData_id = CommonUtils.getAppMetaData(MintsApplication.getContext(), "TD_KEY");
            String td_channel_id = CommonUtils.getAppMetaData(MintsApplication.getContext(), "CHANNEL_NAME");
            TCAgent.init(this, talkingData_id, td_channel_id);
            TCAgent.setReportUncaughtExceptions(true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 友盟初始化
     */
    public void initUm(Context context) {
        try {
            /*
             * 参数4:设备类型，必须参数，传参数为UMConfigure.DEVICE_TYPE_PHONE则表示手机；传参数为UMConfigure.DEVICE_TYPE_BOX则表示盒子；默认为手机。
             * 参数5:Push推送业务的secret，需要集成Push功能时必须传入Push的secret，否则传空。
             */
            UMConfigure.init(context, CommonUtils.getAppMetaData(MintsApplication.getContext(), "UMENG_KEY"), CommonUtils.getAppMetaData(context, "CHANNEL_NAME"), UMConfigure.DEVICE_TYPE_PHONE, "");
            UMConfigure.setLogEnabled(BuildConfig.DEBUG);
            MobclickAgent.setPageCollectionMode(MobclickAgent.PageMode.LEGACY_MANUAL);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * app退出
     */
    public void exitApp() {
        Intent intent = new Intent();
        intent.setAction(Constant.ACTION_EXIT_APP);
        intent.addCategory(Intent.CATEGORY_DEFAULT);
        MintsApplication.getLocalBroadcastManager().sendBroadcast(intent);

        System.gc();
    }

    /**
     * 获得LocalBroadcastManager对象
     */
    public static LocalBroadcastManager getLocalBroadcastManager() {
        if (mLocalBroadcastManager == null) {
            mLocalBroadcastManager = LocalBroadcastManager.getInstance(mContext);
        }
        return mLocalBroadcastManager;
    }

    public LoanService getLoanService() {
        if (loanService == null) {
            loanService = LoanService.Factory.create();
        }
        return loanService;
    }

    public Scheduler defaultSubscribeScheduler() {
        if (defaultSubscribeScheduler == null) {
            defaultSubscribeScheduler = Schedulers.from(Executors.newFixedThreadPool(10));
        }
        return defaultSubscribeScheduler;
    }

    private String getProcessName(Context context) {
        if (context == null) return null;
        ActivityManager manager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        if (manager != null) {
            for (ActivityManager.RunningAppProcessInfo processInfo : manager.getRunningAppProcesses()) {
                if (processInfo.pid == android.os.Process.myPid()) {
                    return processInfo.processName;
                }
            }
        }
        return null;
    }

    /**
     * 初始化toast
     */
    private void initToast() {
        try {
            ToastUtils.init(this);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
