package com.mints.goodmoney.ad.banner

import android.view.View
import android.widget.FrameLayout
import com.bytedance.sdk.openadsdk.AdSlot
import com.bytedance.sdk.openadsdk.TTAdNative
import com.bytedance.sdk.openadsdk.TTNativeExpressAd
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.manager.TtCsjAdManager
import com.mints.goodmoney.utils.LogUtil

/**
 * banner管理
 */
object BannerManager {

    private var adNative: TTAdNative? = null
    private var mTTAd: TTNativeExpressAd? = null

    fun init() {
        adNative = TtCsjAdManager.get().createAdNative(MintsApplication.getContext())

        // 权限请求
        TtCsjAdManager.get().requestPermissionIfNecessary(MintsApplication.getContext())
    }

    /**
     * 获取穿山甲banner
     */
    fun getTtBanner(codeId: String, frameLayout: FrameLayout?) {
        var expressViewAcceptedSizeWidth = 380f
        var expressViewAcceptedSizeHeight = 280f
        when (codeId) {
            TtCsjAdManager.TT_AD_BANNER_MY -> {
                expressViewAcceptedSizeWidth = 380f
                expressViewAcceptedSizeHeight = 280f
            }
        }

//        ToastUtil.showLong(MintsApplication.getContext(), "csj banner:$codeId")

        adNative?.let {
            val adSlot = AdSlot.Builder()
                    .setCodeId(codeId) //广告位id
                    .setSupportDeepLink(true)
                    .setAdCount(1) //请求广告数量为1到3条
                    .setNativeAdType(AdSlot.TYPE_BANNER)
                    .setExpressViewAcceptedSize(expressViewAcceptedSizeWidth, expressViewAcceptedSizeHeight) //期望模板广告view的size,单位dp
                    .setImageAcceptedSize(640, 320) //这个参数设置即可，不影响模板广告的size
                    .build()
            it.loadBannerExpressAd(adSlot, object : TTAdNative.NativeExpressAdListener {
                override fun onNativeExpressAdLoad(ads: MutableList<TTNativeExpressAd>?) {
                    if (ads == null || ads.size == 0) return

                    mTTAd = ads[0]
                    bindAdListener(frameLayout)
                    mTTAd?.render()
                }

                override fun onError(code: Int, msg: String) {
                    LogUtil.d("BannerManager", "onError  code:${code}  msg:${msg}")
                }
            })
        }
    }

    private fun bindAdListener(frameLayout: FrameLayout?) {
        mTTAd?.let {
            it.setExpressInteractionListener(object : TTNativeExpressAd.ExpressAdInteractionListener {
                override fun onAdClicked(p0: View?, p1: Int) {

                }

                override fun onAdShow(p0: View?, p1: Int) {

                }

                override fun onRenderSuccess(view: View, p1: Float, p2: Float) {
                    frameLayout?.let {
                        it.visibility = View.VISIBLE
                        it.removeAllViews()
                        it.addView(view)
                    }
                }

                override fun onRenderFail(p0: View?, p1: String?, p2: Int) {

                }
            })
        }
    }

    fun onDestroy() {
        mTTAd?.let {
            it.setExpressInteractionListener(null)
            it.destroy()
            mTTAd = null
        }
        adNative = null
    }
}