package com.mints.goodmoney.ad.express;

import android.content.Context;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Message;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.manager.TTNativeExpressManager;

public class TTPreLoadCarrierExpressManager {

    private static TTPreLoadCarrierExpressManager _inst;

    private FrameLayout ttFrameLayout;
    private TTNativeExpressManager ttNativeExpressManager;

    private HandlerThread mHandlerThread;
    private Handler mWorkHandler;

    private int mTTPreLoadWhat = 0x3243434;

    public static TTPreLoadCarrierExpressManager getInstance() {
        if (_inst == null) {
            _inst = new TTPreLoadCarrierExpressManager();
        }
        return _inst;
    }

    private TTPreLoadCarrierExpressManager() {
        init();
    }

    private void init() {
        ttNativeExpressManager = new TTNativeExpressManager();
        ttNativeExpressManager.initTTAd(false);

        // 启动异步线程
        mHandlerThread = new HandlerThread("TTPreLoadHandlerThread");
        mHandlerThread.start();

        mWorkHandler = new Handler(mHandlerThread.getLooper()) {
            @Override
            public void handleMessage(@NonNull Message msg) {
                super.handleMessage(msg);

                // 工作线程进行加载数据
                if (msg.what == mTTPreLoadWhat) {
                    loadTtFrameLayoutInThread((String) msg.obj);
                }
            }
        };
    }

    public void onDestroy() {
        if (ttNativeExpressManager != null) {
            ttNativeExpressManager.onTTAdDestroy();
            ttNativeExpressManager = null;
        }
        if (mHandlerThread != null) {
            mHandlerThread.quit();
            mHandlerThread = null;
        }
        if (mWorkHandler != null) {
            mWorkHandler.removeCallbacksAndMessages(null);
            mWorkHandler = null;
        }
    }

    public FrameLayout getTtFrameLayout() {
        return ttFrameLayout;
    }

    private void loadTtFrameLayoutInThread(String codeId) {
        Context context = MintsApplication.getContext();
        ttFrameLayout = null;
        try {
            ttFrameLayout = new FrameLayout(context);
            ttNativeExpressManager.getNativeExpressInit(codeId, ttFrameLayout, 340, 0);
            ttNativeExpressManager.setTTNativeExpressManagerListener(view -> {

                if (view == null) {
                    ttFrameLayout = null;
                } else {

                    try {
                        ttFrameLayout = view;
                    } catch (Exception e) {
                        e.printStackTrace();
                        ttFrameLayout = null;
                    }
                }
            });

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 预加载 信息流
     */
    public void loadTtFrameLayout(String codeId) {
//        init();

//        ToastUtil.showLong(MintsApplication.getContext(), "通用信息流:" + codeId);

        if (mWorkHandler != null) {
            Message msg = Message.obtain();
            msg.what = mTTPreLoadWhat;
            msg.obj = codeId;
            mWorkHandler.sendMessage(msg);
        }
    }
}
