package com.mints.goodmoney.ad.video

import android.app.Activity
import android.content.DialogInterface
import android.text.TextUtils
import android.view.KeyEvent
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.mvp.views.BaseView
import com.mints.goodmoney.ui.widgets.LoadingDialog
import com.mints.goodmoney.utils.ToastUtil
import java.util.HashMap

open class BaseVideoAd(activity: Activity) : BaseView {
    open var activity: Activity? = null
    var progressDialog: LoadingDialog? = null

    init {
        this.activity = activity
    }

    override fun getBaseApplication(): MintsApplication {
        return activity?.getApplication() as MintsApplication
    }

    /**
     * 显示加载进度条（自定义message）
     *
     * @param message
     */
    override fun showLoading(message: String?) {
        if (activity != null) {
            if (activity!!.getWindow() != null && !activity!!.isFinishing()) {
                if (progressDialog == null) {
                    progressDialog = LoadingDialog(activity)
                    progressDialog!!.setLoadText(message)
                }
                progressDialog?.show()
                setProgressOnTouchOutside(false)
                setProgressNoDismiss()
            }
        }

    }

    /**
     * 设置Progress是否手触消失
     *
     * @param onTouchOutside
     */
    open fun setProgressOnTouchOutside(onTouchOutside: Boolean) {
        if (progressDialog != null) progressDialog!!.setCanceledOnTouchOutside(onTouchOutside)
    }

    /**
     * 设置点击返回是否消失加载进度条
     */
    fun setProgressNoDismiss() {
        if (progressDialog != null && progressDialog!!.isShowing()) {
            progressDialog!!.setOnKeyListener(DialogInterface.OnKeyListener { dialog, keyCode, event ->
                keyCode == KeyEvent.KEYCODE_BACK
            })
        }
    }

    /**
     * 消失加载进度条
     */
    override fun hideLoading() {
        try {
            if (activity != null) {
                if (activity!!.getWindow() != null && !activity!!.isFinishing()) {
                    if (progressDialog != null && progressDialog!!.isShowing()) {
                        progressDialog!!.dismiss()
                        progressDialog = null
                    }
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        } finally {
            progressDialog = null
        }
    }

    override fun showToast(msg: String?) {
        if (!TextUtils.isEmpty(msg)) ToastUtil.show(MintsApplication.getContext(), msg)
    }

    /**
     * 激励视频请求接口封装
     */
    fun getAdMapVO(carrierType: String, adsource: String, extraId: String?, curCoin: Int): HashMap<String, Any> {
        val vo = HashMap<String, Any>()
        vo["carrierType"] = carrierType
        vo["adtype"] = Constant.ADTYPE_VEDIO
        vo["adsource"] = adsource
        var tempExtraId = ""
        if (extraId != null) {
            tempExtraId = extraId
        }

        when (carrierType) {
            Constant.CARRIER_VERSUS_VIDEO -> vo["coin"] = curCoin
            Constant.CARRIER_HOMEWATER -> vo["waterCoin"] = curCoin
            Constant.CARRIER_OFFLINE_DOUBLE -> vo["offline_income"] = curCoin
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD -> vo["turntableKey"] = tempExtraId
        }
        return vo
    }

    open fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {}

    open fun onDestroy() {}
}