package com.mints.goodmoney.ad.video

import android.app.Activity
import com.maplehaze.adsdk.video.RewardVideoAd
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.MhManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.mvp.presenters.MhVideoAdPresenter
import com.mints.goodmoney.mvp.views.VideoAdManagerView
import com.mints.goodmoney.utils.LogUtil

private val TAG = MhVideoAdManager::class.java.simpleName

/**
 * 枫岚广告视频
 */
class MhVideoAdManager private constructor(activity: Activity) :
        BaseVideoAd(activity), VideoAdManagerView {

    private var mhVideoAdPresenter: MhVideoAdPresenter? = null
    private var mhVideoAdListener: MhVideoAdListener? = null
    private var mRewardVideoAd: RewardVideoAd? = null

    private var isClickScreen: Boolean = true
    override var activity: Activity? = null

    companion object {
        private var _inst: MhVideoAdManager? = null
        fun getInstance(activity: Activity): MhVideoAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = MhVideoAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
        mhVideoAdPresenter = MhVideoAdPresenter()
        mhVideoAdPresenter?.attachView(this)
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        val postId: String = when (carrierType) {
            Constant.CARRIER_VERSUS_VIDEO -> MhManager.POS_ID
            Constant.CARRIER_HOMEWATER -> MhManager.POS_ID
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_DRAWCASH -> MhManager.POS_ID
            Constant.CARRIER_CHALLENGE_CARD -> MhManager.POS_ID
            else -> MhManager.POS_ID
        }

        val orientation = RewardVideoAd.VERTICAL

        mRewardVideoAd = RewardVideoAd(activity, MhManager.APP_ID, postId, orientation, object : RewardVideoAd.RewardVideoListener {
            override fun onADCached() {
                LogUtil.d(TAG, "onADCached")
                mRewardVideoAd?.showAd(activity)
            }

            override fun onADShow() {
                LogUtil.d(TAG, "onADShow")
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_ZERO, "", "")
            }

            override fun onReward() {
                LogUtil.d(TAG, "onReward")
            }

            override fun onADClick() {
                if (AppConfig.needReportClickAdEvent) {
                    TrackManager.getInstance().reportClickAdEvent()
                }

                LogUtil.d(TAG, "onADClick")
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_TWO, "", "")
                if (isClickScreen) {
                    // 防止重复
                    TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_FOUR, "", "")
                    isClickScreen = false
                }
                if (mhVideoAdListener != null) {
                    mhVideoAdListener?.mhVideoAdDownload()
                }
            }

            override fun onVideoComplete() {
                LogUtil.d(TAG, "onVideoComplete")
            }

            override fun onADClose() {
                LogUtil.d(TAG, "onADClose")

                mhVideoAdPresenter?.reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_FL, extraId, curCoin))

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_THREE, "", "")

                if (mhVideoAdListener != null) {
                    mhVideoAdListener?.mhVideoAdSuccess()
                }
            }

            override fun onADError(p0: Int) {
                LogUtil.d(TAG, "onADError->$p0")

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_ONE, (p0).toString(), "")

                if (mhVideoAdListener != null) {
                    mhVideoAdListener?.mhVideoAdFail()
                }
            }

        })

        mRewardVideoAd?.loadAd()
    }

    fun setMhVideoAdListener(mhVideoAdListener: MhVideoAdListener?) {
        this.mhVideoAdListener = mhVideoAdListener
    }

    interface MhVideoAdListener {
        fun mhVideoAdSuccess()
        fun mhVideoAdFail()
        fun mhVideoAdDownload()
    }

    override fun onDestroy() {
        mhVideoAdPresenter?.let {
            it.dispose()
            it.detachView()
        }

        mRewardVideoAd = null
        activity = null
    }
}