package com.mints.goodmoney.ad.video

import android.app.Activity
import android.text.TextUtils
import androidx.annotation.Nullable
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.MD5
import com.mints.library.utils.json.JsonUtil
import com.tz.sdk.coral.ad.CoralAD
import com.tz.sdk.coral.callback.CoralVideoListener
import com.tz.sdk.core.ad.ADError
import com.tz.sdk.core.ad.ADSource
import com.tz.sdk.core.ad.ADType
import com.tz.sdk.core.loader.ADLoader
import net.grandcentrix.tray.AppPreferences

private val TAG = ShVideoAdManager::class.java.simpleName

/**
 * 天卓珊瑚广告视频
 */
class ShVideoAdManager private constructor(activity: Activity) :
        BaseVideoAd(activity) {

    private var isClickScreen: Boolean = true

    private var shVideoAdListener: ShVideoAdListener? = null
    private lateinit var ps: AppPreferences

    companion object {

        /**
         * taskType 珊瑚的任务类型
         * 104（正式环境使用，珊瑚和广点通、快手视频混出）
         * 131（测试环境使用，广点通视频单出）
         */
        const val TZ_REWRAD_TYPE_DEBUG = 131
        const val TZ_REWRAD_TYPE_RELEASE = 104

        private var _inst: ShVideoAdManager? = null
        fun getInstance(activity: Activity): ShVideoAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = ShVideoAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
        ps = AppPreferences(activity)
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        val type = TZ_REWRAD_TYPE_RELEASE

        ADLoader(activity)
                .get(ADType.REWARD_VIDEO)
                .from(ADSource.CORAL)
                .reward(true)
                .count(1)
                .with(object : HashMap<String?, Any?>() {
                    init {
                        put(CoralAD.Key.TASK_TYPE, type)
                        put(CoralAD.Key.ACCOUNT_ID, UserManager.getInstance().userID)
                        put(CoralAD.Key.LOGIN_KEY, JsonUtil.toJson(getAdMapVO(curCoin, carrierType, extraId)))
//                        put(CoralAD.Key.VIDEO_AUTO_PLAY, true) //拉取成功后是否自动播放视频，非必须，默认true
                    }
                })
                .load(object : CoralVideoListener() {
                    override fun onAdLoaded(adList: List<CoralAD>?) {
                        LogUtil.d(TAG, "onAdLoaded")
//                        if (adList != null && adList.isNotEmpty()) {
//                            val ad = adList[0]
//                            ad.playVideo(activity)
//                        } else {
//
//                        }
                    }

                    override fun onAdFailed(adError: ADError) {
                        LogUtil.d(TAG, "onAdFailed")

                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SH, Constant.EVENT_TYPE_ONE, (adError.code).toString(), "")

                        if (shVideoAdListener != null) {
                            shVideoAdListener?.shVideoAdFail()
                        }
                    }

                    override fun onAdShow(@Nullable ad: CoralAD?): Boolean {
                        LogUtil.d(TAG, "onAdShow")

                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SH, Constant.EVENT_TYPE_ZERO, "", "")
                        return super.onAdShow(ad)
                    }

                    override fun onAdClicked(@Nullable ad: CoralAD?): Boolean {
                        LogUtil.d(TAG, "onADClick")

                        if (AppConfig.needReportClickAdEvent) {
                            TrackManager.getInstance().reportClickAdEvent()
                        }

                        if (isClickScreen) {
                            // 防止重复
                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SH, Constant.EVENT_TYPE_FOUR, "", "")
                            isClickScreen = false
                        }
                        if (shVideoAdListener != null) {
                            shVideoAdListener?.shVideoAdDownload()
                        }

                        return super.onAdClicked(ad)
                    }

                    override fun onAppDownloading(@Nullable ad: CoralAD?, @Nullable downloadUrl: String?): Boolean {
                        LogUtil.d(TAG, "onAppDownloading")

                        return super.onAppDownloading(ad, downloadUrl)
                    }

                    override fun onAppDownloaded(@Nullable ad: CoralAD?, @Nullable downloadUrl: String?, @Nullable localFile: String?): Boolean {
                        LogUtil.d(TAG, "onAppDownloaded")

                        return super.onAppDownloaded(ad, downloadUrl, localFile)
                    }

                    override fun onAppInstalled(@Nullable ad: CoralAD?, @Nullable downloadUrl: String?, @Nullable localFile: String?): Boolean {
                        LogUtil.d(TAG, "onAppInstalled")

                        return super.onAppInstalled(ad, downloadUrl, localFile)
                    }

                    override fun onAppActivated(ad: CoralAD?, downloadUrl: String?, localFile: String?): Boolean {
                        LogUtil.d(TAG, "onAppActivated")

                        return super.onAppActivated(ad, downloadUrl, localFile)
                    }

                    override fun onVideoFinished(@Nullable coralAD: CoralAD?, @Nullable s: String?): Boolean {
                        LogUtil.d(TAG, "onVideoFinished")

                        return super.onVideoFinished(coralAD, s)
                    }

                    override fun onVideoClosed(@Nullable coralAD: CoralAD?, @Nullable s: String?): Boolean {
                        LogUtil.d(TAG, "onVideoClosed")
                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SH, Constant.EVENT_TYPE_THREE, "", "")

                        if (shVideoAdListener != null) {
                            shVideoAdListener?.shVideoAdSuccess()
                        }

                        return super.onVideoClosed(coralAD, s)
                    }
                })

    }

    fun setShVideoAdListener(shVideoAdListener: ShVideoAdListener?) {
        this.shVideoAdListener = shVideoAdListener
    }

    interface ShVideoAdListener {
        fun shVideoAdSuccess()
        fun shVideoAdFail()
        fun shVideoAdDownload()
    }

    override fun onDestroy() {
        activity = null
    }

    private fun getAdMapVO(curCoin: Int, carrierType: String, extraId: String?): HashMap<String, Any> {
        val vo = HashMap<String, Any>()
        vo["carrierType"] = carrierType
        vo["adtype"] = Constant.ADTYPE_VEDIO
        vo["tid"] = MD5.GetMD5Code(System.currentTimeMillis().toString() + UserManager.getInstance().userID)
        vo["ip"] = ps.getString(Constant.CSJ_VEDIO_APPIP, "")!!
        when (carrierType) {
            Constant.CARRIER_VERSUS_VIDEO -> vo["coin"] = curCoin
            Constant.CARRIER_HOMEWATER -> vo["waterCoin"] = curCoin
            Constant.CARRIER_OFFLINE_DOUBLE -> {
                vo["offline_income"] = curCoin
                vo["turntableKey"] = if (TextUtils.isEmpty(extraId)) "" else extraId!!
            }
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD -> vo["turntableKey"] = if (TextUtils.isEmpty(extraId)) "" else extraId!!
        }
        return vo
    }
}