package com.mints.goodmoney.ad.video;

import android.app.Activity;
import android.text.TextUtils;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.common.AppConfig;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.mvp.model.VideoAdingBean;
import com.mints.goodmoney.mvp.model.WeightBean;
import com.mints.goodmoney.utils.LogUtil;
import com.mints.goodmoney.utils.ToastUtil;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Random;

/**
 * 视频广告播放
 */
public class VideoAdingManager {

    private static final String TAG = VideoAdingManager.class.getSimpleName();

    private static VideoAdingManager _inst;

    private VideoAdingListener videoAdingListener;

    private WnVideoAdManager wnVideoAdManager;
    private CsjVideoAdManager csjVideoAdManager;
    private YlhVideoAdManager ylhVideoAdManager;
    private MhVideoAdManager mhVideoAdManager;
    private ShVideoAdManager shVideoAdManager;
    private CsjFullVideoAdManager csjFullVideoAdManager;

    private int wnWeight;
    private int ylhWeight;
    private int csjVideoWeight;
    private int flVideoWeight;
    private int shVideoWeight;
    private int csjFullVideoWeight;

    private ArrayList<WeightBean> weightList;

    // 是否是高额视频任务
    private boolean isHighWeight = false;
    private boolean isTTVideoAd = false;

    private Activity activity;
    private boolean isVideoAdDownload = false;// 是否点击广告下载 true-点击

    public static VideoAdingManager getInstance(Activity activity) {
        if (_inst == null) {
            WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
            _inst = new VideoAdingManager(activityWeakReference.get());
        }
        return _inst;
    }

    private VideoAdingManager(Activity activity) {
        init(activity);
    }

    /**
     * 初始化广告manager
     *
     * @param activity
     */
    private void init(Activity activity) {
        this.activity = activity;
        csjVideoAdManager = CsjVideoAdManager.getInstance(activity);
        ylhVideoAdManager = YlhVideoAdManager.getInstance(activity);
        wnVideoAdManager = WnVideoAdManager.Companion.getInstance(activity);
        mhVideoAdManager = MhVideoAdManager.Companion.getInstance(activity);
        shVideoAdManager = ShVideoAdManager.Companion.getInstance(activity);
        csjFullVideoAdManager = CsjFullVideoAdManager.getInstance(activity);
        weightList = new ArrayList<>();
    }

    /**
     * 初始化广告权重
     */
    public void initAdWeight(int csjVideoWeight, int ylhWeight, int wnWeight, int flVideoWeight, int shVideoWeight, int csjFullVideoWeight) {
        this.csjVideoWeight = csjVideoWeight;
        this.ylhWeight = ylhWeight;
        this.wnWeight = wnWeight;
        this.flVideoWeight = flVideoWeight;
        this.shVideoWeight = shVideoWeight;
        this.csjFullVideoWeight = csjFullVideoWeight;
    }

    /**
     * 根据类型加载对应视频(第一次加载)
     *
     * @param bean
     */
    public void loadAding(Activity activity, VideoAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();
        isVideoAdDownload = false;

        if (AppConfig.flVideoFlag) {
            // 先展示枫岚视频
            firstLoadFlVideo(bean);
        } else {
            // 权重自有逻辑
            loadAdVideo(getVideoAdType(), bean);
        }
    }

    /**
     * 根据载体优先加载枫岚
     *
     * @param bean
     */
    private void firstLoadFlVideo(VideoAdingBean bean) {
        String adType;
        switch (bean.getCarrierType()) {
            case Constant.CARRIER_VERSUS_VIDEO:
            case Constant.CARRIER_HOMEWATER:
            case Constant.CARRIER_WALK:
            case Constant.CARRIER_WALK_BUBBLE:
            case Constant.CARRIER_SIGNIN_HOMEPAGE_CARD:
            case Constant.CARRIER_OFFLINE_DOUBLE:
            case Constant.CARRIER_EATMEAL_SUBSIDY:
                adType = Constant.FL_VEDIO_AD;
//                ToastUtil.showLong(activity, "载体优先类型：" + Constant.FL_VEDIO_AD);
                break;
            default:
                adType = getVideoAdType();
                break;
        }
        loadAdVideo(adType, bean);
    }

    /**
     * 加载失败优先级对应视频
     *
     * @param bean
     */
    public void loadFailAding(Activity activity, VideoAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();

        isVideoAdDownload = false;
        loadAdVideo(getNextAdType(), bean);
    }

    /**
     * 根据广告优先级获取下一个
     */
    private String getNextAdType() {
        String nextAdType;
        if (AppConfig.csjVideoAdCount > 0) {
            nextAdType = Constant.CSJ_VEDIO_AD;
        } else if (AppConfig.ylhAdCount > 0) {
            nextAdType = Constant.YLH_VEDIO_AD;
        } else if (AppConfig.csjFullVedioAdCount > 0) {
            nextAdType = Constant.CSJ_FULL_AD;
        } else if (AppConfig.shVideoAdCount > 0) {
            nextAdType = Constant.SH_VEDIO_AD;
        } else {
            nextAdType = Constant.FL_VEDIO_AD;
        }
        return nextAdType;
    }

    /**
     * 获取广告类型配置
     */
    private String getVideoAdType() {
        // 根据权重获取广告类型
        String adType;
        if (isHighWeight) {
            adType = getHighWeight();
        } else {
            adType = getRandomWeight();
        }
        isHighWeight = false;

        LogUtil.d(TAG, "权重结果返回的广告类型：" + adType);
        return adType;
    }

    public void setIsHighWeight(boolean isHighWeight) {
        this.isHighWeight = isHighWeight;
    }

    /**
     * 高额任务广告类型
     *
     * @return
     */
    private String getHighWeight() {
        isTTVideoAd = !isTTVideoAd;
        if (isTTVideoAd) {
            return Constant.CSJ_VEDIO_AD;
        } else {
            return Constant.YLH_VEDIO_AD;
        }
    }

    /**
     * 根据权重获取广告类型
     *
     * @return
     */
    private String getRandomWeight() {
        if (weightList != null) {
            weightList.clear();
        }
        int weight = 0;
        // 若没有视频完成数，不加入权重计算范围内
        if (AppConfig.csjVideoAdCount > 0) {
            weightList.add(new WeightBean(csjVideoWeight, Constant.CSJ_VEDIO_AD));
            weight = weight + csjVideoWeight;
            LogUtil.d(TAG, "权重值：csjVideoWeight:" + csjVideoWeight);
        }
        if (AppConfig.ylhAdCount > 0) {
            weightList.add(new WeightBean(ylhWeight, Constant.YLH_VEDIO_AD));
            weight = weight + ylhWeight;
            LogUtil.d(TAG, "权重值：ylhWeight:" + ylhWeight);
        }
        if (AppConfig.csjFullVedioAdCount > 0) {
            weightList.add(new WeightBean(csjFullVideoWeight, Constant.CSJ_FULL_AD));
            weight = weight + csjFullVideoWeight;
            LogUtil.d(TAG, "权重值：csjFullVedioWeight:" + csjFullVideoWeight);
        }
        if (AppConfig.flVideoAdCount > 0) {
            weightList.add(new WeightBean(flVideoWeight, Constant.FL_VEDIO_AD));
            weight = weight + flVideoWeight;
            LogUtil.d(TAG, "权重值：flVideoWeight:" + flVideoWeight);
        }
        if (AppConfig.wnVideoAdCount > 0) {
            weightList.add(new WeightBean(wnWeight, Constant.SDHZ_VEDIO_AD));
            weight = weight + wnWeight;
            LogUtil.d(TAG, "权重值：sdhzWeight:" + wnWeight);
        }
        if (AppConfig.shVideoAdCount > 0) {
            weightList.add(new WeightBean(shVideoWeight, Constant.SH_VEDIO_AD));
            weight = weight + shVideoWeight;
            LogUtil.d(TAG, "权重值：shWeight:" + shVideoWeight);
        }

        // 权重随机
        if (weightList != null && weightList.size() > 0 && weight > 0) {
            LogUtil.d(TAG, "1、权重总值：" + weight);
            Random r = new Random();
            int randomWeight = r.nextInt(weight) + 1;
            LogUtil.d(TAG, "2、权重随机值：" + randomWeight);
            ToastUtil.show(MintsApplication.getContext(),"权重随机值：" + randomWeight);
            for (WeightBean weightBean : weightList) {
                randomWeight -= weightBean.getWeight();
                if (randomWeight <= 0) {
                    LogUtil.d(TAG, "3、权重结果：" + weightBean.getType());
                    return weightBean.getType();
                }
            }
        }
        return "";
    }

    /**
     * 是否点击下载
     *
     * @return
     */
    public boolean isVideoAdDownload() {
        return this.isVideoAdDownload;
    }

    /**
     * 获取所有视频完成数状态  true-无可看视频
     *
     * @return
     */
    public boolean getVideoFinishFlag() {
        int csjVideoAdCount = AppConfig.csjVideoAdCount;
        int ylhAdCount = AppConfig.ylhAdCount;
        int wnAdCount = AppConfig.wnVideoAdCount;
        int flVideoAdCount = AppConfig.flVideoAdCount;
        int tzVideoAdCount = AppConfig.shVideoAdCount;

        if (ylhAdCount <= 0 && csjVideoAdCount <= 0 && wnAdCount <= 0 && flVideoAdCount <= 0 && tzVideoAdCount <= 0) {
//            showToast("今日视频已看完，请明天再来吧");
            return true;
        }
        return false;
    }

    /**
     * 释放资源
     */
    public void onDestory() {
        if (csjVideoAdManager != null) {
            csjVideoAdManager.setCsjVideoAdListener(null);
            csjVideoAdManager.onDestroy();
            csjVideoAdManager = null;
        }
        if (ylhVideoAdManager != null) {
            ylhVideoAdManager.setYlhVideoAdListener(null);
            ylhVideoAdManager.onDestroy();
            ylhVideoAdManager = null;
        }
        if (wnVideoAdManager != null) {
            wnVideoAdManager.setWnVideoAdListener(null);
            wnVideoAdManager.onDestroy();
            wnVideoAdManager = null;
        }
        if (mhVideoAdManager != null) {
            mhVideoAdManager.setMhVideoAdListener(null);
            mhVideoAdManager.onDestroy();
            mhVideoAdManager = null;
        }
        if (csjFullVideoAdManager != null) {
            csjFullVideoAdManager.setCsjFullVedioAdListener(null);
            csjFullVideoAdManager.onDestroy();
            csjFullVideoAdManager = null;
        }
        if (shVideoAdManager != null) {
            shVideoAdManager.setShVideoAdListener(null);
            shVideoAdManager.onDestroy();
            shVideoAdManager = null;
        }

        activity = null;
    }

    public void setVideoAdingListener(VideoAdingListener videoAdingListener) {
        this.videoAdingListener = videoAdingListener;
    }

    /**
     * 加载成功失败回调
     */
    public interface VideoAdingListener {
        void videoAdingListenerError(String adType);

        void videoAdingListenerFail(String adType);

        void videoAdingListenerSuccess(String adType);
    }

    /**
     * 展示视频
     *
     * @param videoAdType
     * @param bean
     */
    private void loadAdVideo(String videoAdType, VideoAdingBean bean) {
        try {
            if (TextUtils.equals(videoAdType, Constant.YLH_VEDIO_AD)) {
                // 优量汇
                if (ylhVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.YLH_VEDIO_AD);
                        }
                        return;
                    }
                    ylhVideoAdManager = YlhVideoAdManager.getInstance(activity);
                }

                ylhVideoAdManager.setYlhVideoAdListener(new YlhVideoAdManager.YlhVideoAdListener() {
                    @Override
                    public void ylhVideoAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void ylhVideoAdSuccess() {
                        AppConfig.ylhAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void ylhVideoAdDownload() {
                        isVideoAdDownload = true;
                    }
                });
                ylhVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.CSJ_VEDIO_AD)) {
                // 穿山甲激励视频
                if (csjVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.CSJ_VEDIO_AD);
                        }
                        return;
                    }
                    csjVideoAdManager = CsjVideoAdManager.getInstance(activity);
                }


                csjVideoAdManager.setCsjVideoAdListener(new CsjVideoAdManager.CsjVideoAdListener() {
                    @Override
                    public void csjVideoAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void csjVideoAdSuccess() {
                        AppConfig.csjVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void csjVideoDownload() {
                        isVideoAdDownload = true;
                    }
                });
                csjVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.SDHZ_VEDIO_AD)) {
                // 闪电盒子激励视频
                if (wnVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.SDHZ_VEDIO_AD);
                        }
                        return;
                    }
                    wnVideoAdManager = WnVideoAdManager.Companion.getInstance(activity);
                }
                wnVideoAdManager.setWnVideoAdListener(new WnVideoAdManager.WnVideoAdListener() {
                    @Override
                    public void wnVideoAdSuccess() {
                        AppConfig.wnVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void wnVideoAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void wnVideoAdDownload() {
                        isVideoAdDownload = true;
                    }
                });
                wnVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.FL_VEDIO_AD)) {
                // 枫岚广告激励视频
                if (mhVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.FL_VEDIO_AD);
                        }
                        return;
                    }
                    mhVideoAdManager = MhVideoAdManager.Companion.getInstance(activity);
                }
                mhVideoAdManager.setMhVideoAdListener(new MhVideoAdManager.MhVideoAdListener() {
                    @Override
                    public void mhVideoAdSuccess() {
                        AppConfig.flVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void mhVideoAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void mhVideoAdDownload() {
                        isVideoAdDownload = true;
                    }
                });

                mhVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.CSJ_FULL_AD)) {
                // 穿山甲全屏广告激励视频
                if (csjFullVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.CSJ_FULL_AD);
                        }
                        return;
                    }
                    csjFullVideoAdManager = CsjFullVideoAdManager.getInstance(activity);
                }
                csjFullVideoAdManager.setCsjFullVedioAdListener(new CsjFullVideoAdManager.CsjFullVedioAdListener() {
                    @Override
                    public void csjFullVedioAdSuccess() {
                        AppConfig.shVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.CSJ_FULL_AD);
                        }
                    }

                    @Override
                    public void csjFullVedioAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.CSJ_FULL_AD);
                        }
                    }

                    @Override
                    public void csjFullVedioDownload() {
                        isVideoAdDownload = true;
                    }
                });

                csjFullVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.SH_VEDIO_AD)) {
                // 珊瑚广告激励视频
                if (shVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.SH_VEDIO_AD);
                        }
                        return;
                    }
                    shVideoAdManager = ShVideoAdManager.Companion.getInstance(activity);
                }
                shVideoAdManager.setShVideoAdListener(new ShVideoAdManager.ShVideoAdListener() {
                    @Override
                    public void shVideoAdSuccess() {
                        AppConfig.shVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.SH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void shVideoAdFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.SH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void shVideoAdDownload() {
                        isVideoAdDownload = true;
                    }
                });

                shVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (videoAdingListener != null) {
                videoAdingListener.videoAdingListenerError(bean.getCarrierType());
            }
        }
    }

}