package com.mints.goodmoney.mvp.presenters;

import android.text.TextUtils;

import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.common.DeviceInfo;
import com.mints.goodmoney.manager.AppHttpManager;
import com.mints.goodmoney.manager.ShumeiManager;
import com.mints.goodmoney.manager.UserManager;
import com.mints.goodmoney.mvp.model.BaseResponse;
import com.mints.goodmoney.mvp.model.UserBean;
import com.mints.goodmoney.mvp.views.AwardView;
import com.mints.goodmoney.utils.DeviceUuidFactory;
import com.mints.goodmoney.utils.rxutil.CommonRxTask;
import com.mints.goodmoney.utils.rxutil.RxjavaUtil;
import com.mints.library.net.neterror.BaseSubscriber;
import com.mints.library.net.neterror.Throwable;

import java.util.HashMap;

public class AwardPresenter extends BasePresenter<AwardView> {

    public void getCoinMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getCoinMsg(),
                        new BaseSubscriber<BaseResponse<JsonObject>>() {
                            @Override
                            public void onCompleted() {
                                if (isLinkView()) return;

                                view.hideLoading();
                            }

                            @Override
                            public void onError(Throwable e) {
                                if (isLinkView()) return;

                                view.hideLoading();
                                view.showToast(e.getMessage());
                            }

                            @Override
                            public void onNext(BaseResponse<JsonObject> baseResponse) {
                                if (isLinkView()) return;

                                int code = baseResponse.getStatus();
                                String message = baseResponse.getMessage();
                                switch (code) {
                                    case 200://成功
                                        JsonObject data = baseResponse.getData();
                                        if (data != null) {
                                            boolean riskFlag = false;
                                            JsonElement riskinfoRateElement = data.get("riskinfoRate");
                                            if (riskinfoRateElement != null) {
                                                riskFlag = data.get("riskinfoRate").getAsBoolean();
                                            }

                                            boolean showHigh = false;
                                            JsonElement showHighElement = data.get("showHigh");
                                            if (showHighElement != null) {
                                                showHigh = data.get("showHigh").getAsBoolean();
                                            }
                                            int highCoin = 3000;
                                            JsonElement highCoinElement = data.get("highCoin");
                                            if (highCoinElement != null) {
                                                highCoin = data.get("highCoin").getAsInt();
                                            }
                                            view.getUserTaskMsgSuc(data.get("coin").getAsInt(), riskFlag, showHigh, highCoin);
                                        }
                                        break;
                                    default:
                                        view.showToast(message);
                                        break;
                                }
                            }
                        });
    }

    public void saveTerminalInfo() {
        DeviceInfo deviceInfo = DeviceInfo.Companion.getInstance();
        RxjavaUtil.executeRxTask(new CommonRxTask<String>("") {
            @Override
            public void doInIOThread() {
                setT(deviceInfo.getAppInfoMap());
            }

            @Override
            public void doInUIThread() {
                HashMap<String, Object> vo = new HashMap<>();
                String macAddress = deviceInfo.getMacAddress();
                if (!TextUtils.isEmpty(macAddress)) {
                    String mac = macAddress.replace(":", "");
                    vo.put("mac", mac);
                    vo.put("mac1", macAddress);
                }
                vo.put("imei", deviceInfo.getIMEI());
                vo.put("androidid", deviceInfo.getAndroidId(null));
                vo.put("os", "android");
                vo.put("shumeiId", ShumeiManager.getInstance().getShumeiDeviceId());
                vo.put("model", deviceInfo.getNewModel());
                vo.put("uuid", new DeviceUuidFactory().getDeviceUuid());
                vo.put("osversion", deviceInfo.getOSVersion());
                vo.put("appversion", deviceInfo.getVersionName());
                vo.put("appPkgList", getT());
                if (!TextUtils.isEmpty(MintsApplication.OAID)) {
                    vo.put("oaid", MintsApplication.OAID);
                }
                AppHttpManager.getInstance(loanApplication)
                        .call(loanService.saveTerminalInfo(vo),
                                new BaseSubscriber<BaseResponse<UserBean>>() {
                                    @Override
                                    public void onCompleted() {
                                        if (isLinkView()) return;

                                        view.hideLoading();
                                    }

                                    @Override
                                    public void onError(Throwable e) {
                                        if (isLinkView()) return;

                                        view.hideLoading();
                                    }

                                    @Override
                                    public void onNext(BaseResponse<UserBean> baseResponse) {
                                        if (isLinkView()) return;

                                        int code = baseResponse.getStatus();
                                        String message = baseResponse.getMessage();
                                        switch (code) {
                                            case 200://成功
                                                break;
                                            default:
                                                view.showToast(message);
                                                break;
                                        }
                                    }
                                });
            }
        });
    }

    public void reportAddCoinMsg(HashMap<String, Object> vo) {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.reportAddCoinMsg(vo),
                        new BaseSubscriber<BaseResponse<Object>>() {
                            @Override
                            public void onCompleted() {
                                if (isLinkView()) return;
                            }

                            @Override
                            public void onError(Throwable e) {
                                if (isLinkView()) return;
                            }

                            @Override
                            public void onNext(BaseResponse<Object> baseResponse) {
                                if (isLinkView()) return;
                            }
                        });
    }

    /**
     * 设置高额任务状态
     * <p>
     * value
     */
    public void setHighTaskType(String value) {
        HashMap<String, Object> vo = new HashMap<>();
        vo.put("carrierType", Constant.CARRIER_HIGH_ACTIVITY);
        vo.put("value", value);
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.setStatusInOneDayByCarrierType(vo), new BaseSubscriber<BaseResponse<Object>>() {
                    @Override
                    public void onError(Throwable e) {

                    }

                    @Override
                    public void onCompleted() {
                        super.onCompleted();
                    }

                    @Override
                    public void onNext(BaseResponse<Object> objectBaseResponse) {
                        if (isLinkView()) return;
                        switch (objectBaseResponse.getStatus()) {
//                            if (!TextUtils.equals(value, "3")) {
////                                getAutoUserHallBaseMsg()
//                            }
                        }
                    }

                });
    }

    public void riskinfo() {
        DeviceInfo deviceInfo = DeviceInfo.Companion.getInstance();
        RxjavaUtil.executeRxTask(new CommonRxTask<String>("") {
            @Override
            public void doInIOThread() {
                setT(deviceInfo.getAppInfoMap());
            }

            @Override
            public void doInUIThread() {
                HashMap<String, Object> vo = new HashMap<>();
                vo.put("androidid", deviceInfo.getAndroidId(null));
                vo.put("os", "android");
                vo.put("model", deviceInfo.getBrand() + " " + deviceInfo.getMobileModel());
                vo.put("uuid", new DeviceUuidFactory().getDeviceUuid());
                vo.put("osversion", deviceInfo.getOSVersion());
                vo.put("appversion", deviceInfo.getVersionName());
                vo.put("applist", getT());
                vo.put("eventid", Constant.RISK_EVENT_ID_TASK);
                vo.put("ischarge", deviceInfo.isCharging());
                vo.put("isusbdebug", deviceInfo.getGetUsbStatus());
                vo.put("iswifi", deviceInfo.getGetWifiConnected());
                vo.put("isroot", deviceInfo.isRoot());
                vo.put("isvpn", deviceInfo.isVPN());
                vo.put("memory", deviceInfo.getTotalMemory() + "+" + deviceInfo.getTotalStorage());
                vo.put("operator", deviceInfo.getOperator());
                vo.put("idfa", "");
                vo.put("imei", deviceInfo.getIMEI());
                vo.put("oaid", MintsApplication.OAID);

                AppHttpManager.getInstance(loanApplication)
                        .call(loanService.riskinfo(vo),
                                new BaseSubscriber<BaseResponse<Object>>() {
                                    @Override
                                    public void onCompleted() {
                                        if (isLinkView()) return;
                                    }

                                    @Override
                                    public void onError(Throwable e) {
                                    }

                                    @Override
                                    public void onNext(BaseResponse<Object> baseResponse) {
                                    }
                                });
            }
        });
    }
}
