package com.mints.goodmoney.mvp.presenters

import com.mints.goodmoney.manager.AppHttpManager
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.MorningClockBean
import com.mints.goodmoney.mvp.views.MorningClockView
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable
import java.util.*

class MorningClockPresenter : BasePresenter<MorningClockView>() {

    /**
     * 早上打卡信息
     */
    open fun getUpEarlySignMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getUpEarlySignMsg(),
                        object : BaseSubscriber<BaseResponse<MorningClockBean>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                                view.hideLoading()
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.hideLoading()
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<MorningClockBean>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                val message = baseResponse.message

                                when (code) {
                                    200 -> view.getUpEarlySignMsgSuc(baseResponse.data)
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    /**
     * 早上打卡
     */
    fun getUpEarlyClickButton(adSource: String) {
        val vo = HashMap<String, Any>()
        vo["adSource"] = adSource
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getUpEarlyClickButton(vo),
                        object : BaseSubscriber<BaseResponse<Any>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<Any>) {
                                if (isLinkView) return
                            }
                        })
    }
}