package com.mints.goodmoney.net;


import android.text.TextUtils;

import com.google.gson.JsonObject;
import com.mints.goodmoney.BuildConfig;
import com.orhanobut.logger.Logger;
import java.util.concurrent.TimeUnit;

import okhttp3.OkHttpClient;
import okhttp3.RequestBody;
import okhttp3.logging.HttpLoggingInterceptor;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava.RxJavaCallAdapterFactory;
import retrofit2.http.Body;
import retrofit2.http.GET;
import retrofit2.http.POST;
import retrofit2.http.Url;
import rx.Observable;

/**
 * 描述：CPD 服务器交互
 * 作者：孟崔广
 * 时间：2021/1/18 13:46
 */
public interface CpdService {

    String CPD_IP = "http://api.musesmobi.com:8111/api/cpd/1/detail/default/";//测试

    /**
     * 请求广告
     *
     * @return
     */
    @POST
    Observable<JsonObject> getAdVedio(@Url String url, @Body RequestBody requestBody);

    /**
     * 提交监测
     *
     * @return
     */
    @GET
    Observable<Object> cmtImp(@Url String url);

    class Factory {

        private Factory() { }

        private static CpdService sCpdService;

        public static CpdService getInstance() {
            if (sCpdService == null) {
                return sCpdService = create();
            } else {
                return sCpdService;
            }
        }

        private static CpdService create() {
            OkHttpClient.Builder builder = new OkHttpClient.Builder();

            builder.retryOnConnectionFailure(false);
            builder.connectTimeout(20, TimeUnit.SECONDS);
            builder.readTimeout(20, TimeUnit.SECONDS);
            builder.writeTimeout(20, TimeUnit.SECONDS);

            if (BuildConfig.DEBUG) {
                HttpLoggingInterceptor logging = new HttpLoggingInterceptor(message -> {
                    if (TextUtils.isEmpty(message)) return;
                    String s = message.substring(0, 1);
                    String request = message.substring(0, 4);
                    if ("{".equals(s) || "[".equals(s)) {
                        Logger.json(message);
                    } else if (request.contains("-->") || request.contains("<--")) {
                        Logger.d("Method" + message);
                    } else {
                        Logger.d("params:" + message);
                    }
                });
                logging.setLevel(HttpLoggingInterceptor.Level.BODY);
                builder.interceptors().add(logging);
            }

            Retrofit retrofit = new Retrofit.Builder()
                    .client(builder.build())
                    .baseUrl(CPD_IP)
                    .addConverterFactory(CommonGsonConverterFactory.create())
                    .addCallAdapterFactory(RxJavaCallAdapterFactory.create())
                    .build();

            return retrofit.create(CpdService.class);
        }
    }
}
