package com.mints.goodmoney.net;

import android.text.TextUtils;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;

class DomainInterceptor implements Interceptor {

    public static Map<String, HttpUrl> sDomainHostUrl = new HashMap<>();

    public static final String DOMAIN_NAME = "domain_name";

    @Override
    public Response intercept(Chain chain) throws IOException {
        return chain.proceed(processRequest(chain.request()));
    }

    private Request processRequest(Request request) {
        if (request == null)
            return null;

        Request.Builder newBuilder = request.newBuilder();

        // 是否有切换标识
        String domain_name = obtainDomainNameFromHeaders(request);
        HttpUrl domain_url;

        if (!TextUtils.isEmpty(domain_name)) {
            domain_url = sDomainHostUrl.get(domain_name);

            // 删除标识header
            newBuilder.removeHeader(DOMAIN_NAME);

            // 更改httpUrl
            if (null != domain_url) {
                HttpUrl httpUrl = request
                        .url()
                        .newBuilder()
                        .scheme(domain_url.scheme())
                        .host(domain_url.host())
                        .port(domain_url.port())
                        .build();

                if (httpUrl.url().toString().contains("api-gm")) {
                    String replaceUrl = httpUrl.url().toString().replace("/api-gm", "");

                    return newBuilder
                            .url(replaceUrl)
                            .build();
                }

                return newBuilder
                        .url(httpUrl.url())
                        .build();
            }
        }

        return newBuilder.build();
    }

    /**
     * @return DomainName
     */
    public static String obtainDomainNameFromHeaders(Request request) {
        List<String> headers = request.headers(DOMAIN_NAME);
        if (headers.size() == 0)
            return null;
        if (headers.size() > 1)
            throw new IllegalArgumentException("Only one Domain-Name in the headers");
        return request.header(DOMAIN_NAME);
    }

}
