package com.mints.goodmoney.service;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;

import com.mints.library.utils.TLog;
import com.mints.goodmoney.ui.activitys.MainActivity;
import com.mints.goodmoney.ui.widgets.CustomDialogAsApple;
import com.mints.goodmoney.ui.widgets.DialogListener;
import com.mints.goodmoney.utils.ForegroundOrBackground;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Iterator;

import cn.jpush.android.api.JPushInterface;

public class JpushReceiver extends BroadcastReceiver {

    private static final String TAG = "JPush";

    private CustomDialogAsApple cdaa;

    @Override
    public void onReceive(Context context, Intent intent) {
        Bundle bundle = intent.getExtras();
        TLog.d(TAG, "[MyReceiver] onReceive - " + intent.getAction() + ", extras: " + printBundle(bundle));

//
        if (JPushInterface.ACTION_REGISTRATION_ID.equals(intent.getAction())) {
            String regId = bundle.getString(JPushInterface.EXTRA_REGISTRATION_ID);
            TLog.d(TAG, "[MyReceiver] 接收Registration Id : " + regId);
            //send the Registration Id to your server...

        } else if (JPushInterface.ACTION_MESSAGE_RECEIVED.equals(intent.getAction())) {
            TLog.d(TAG, "[MyReceiver] 接收到推送下来的自定义消息: " + bundle.getString(JPushInterface.EXTRA_MESSAGE));
//            processCustomMessage(context, bundle);

        } else if (JPushInterface.ACTION_NOTIFICATION_RECEIVED.equals(intent.getAction())) {
            TLog.d(TAG, "[MyReceiver] 接收到推送下来的通知");
            int notifactionId = bundle.getInt(JPushInterface.EXTRA_NOTIFICATION_ID);
            String alert = bundle.getString(JPushInterface.EXTRA_ALERT);

            TLog.d(TAG, "[MyReceiver] 接收到推送下来的通知的ID: " + notifactionId);

            String type = null;
            try {
                JSONObject json = new JSONObject(bundle.getString(JPushInterface.EXTRA_EXTRA));
                type = json.getString("type");
            } catch (JSONException e) {
                TLog.e(TAG, "Get message extra JSON error!");
            }

            if (TextUtils.equals(type, "02") && !TextUtils.isEmpty(alert)) {
                Activity forwardActivity = ForegroundOrBackground.getApp_activity();
                try {
                    if (forwardActivity != null && !forwardActivity.isFinishing() && forwardActivity.hasWindowFocus()) {
                        cdaa = new CustomDialogAsApple(forwardActivity, new DialogListener() {
                            @Override
                            public void onClick(View v) {
                                if (cdaa != null && cdaa.isShowing()) {
                                    cdaa.dismiss();
                                }
                            }
                        });
                        cdaa.setContent(alert);
                        cdaa.setLeft("确定");
                        cdaa.show();
                    }
                } catch (Exception e) {
                }
            }

        } else if (JPushInterface.ACTION_NOTIFICATION_OPENED.equals(intent.getAction())) {
            TLog.d(TAG, "[MyReceiver] 用户点击打开了通知");
            String type = null;
            try {
                JSONObject json = new JSONObject(bundle.getString(JPushInterface.EXTRA_EXTRA));
                type = json.getString("type");
            } catch (JSONException e) {
                TLog.e(TAG, "Get message extra JSON error!");
            }
            Intent i;
            if (TextUtils.equals(type, "01")) {
//                i = new Intent(context, DrinkClockActivity.class);
            } else {
                i = new Intent(context, MainActivity.class);
            }
            i = new Intent(context, MainActivity.class);
            i.putExtras(bundle);
            i.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TOP);
            context.startActivity(i);

        } else if (JPushInterface.ACTION_RICHPUSH_CALLBACK.equals(intent.getAction())) {
            TLog.d(TAG, "[MyReceiver] 用户收到到RICH PUSH CALLBACK: " + bundle.getString(JPushInterface.EXTRA_EXTRA));
            //在这里根据 JPushInterface.EXTRA_EXTRA 的内容处理代码，比如打开新的Activity， 打开一个网页等..

        } else if (JPushInterface.ACTION_CONNECTION_CHANGE.equals(intent.getAction())) {
            boolean connected = intent.getBooleanExtra(JPushInterface.EXTRA_CONNECTION_CHANGE, false);
            TLog.w(TAG, "[MyReceiver]" + intent.getAction() + " connected state change to " + connected);
        } else {
            TLog.d(TAG, "[MyReceiver] Unhandled intent - " + intent.getAction());
        }
    }

    // 打印所有的 intent extra 数据
    private static String printBundle(Bundle bundle) {
        StringBuilder sb = new StringBuilder();
        for (String key : bundle.keySet()) {
            if (key.equals(JPushInterface.EXTRA_NOTIFICATION_ID)) {
                sb.append("\nkey:" + key + ", value:" + bundle.getInt(key));
            } else if (key.equals(JPushInterface.EXTRA_CONNECTION_CHANGE)) {
                sb.append("\nkey:" + key + ", value:" + bundle.getBoolean(key));
            } else if (key.equals(JPushInterface.EXTRA_EXTRA)) {
                if (bundle.getString(JPushInterface.EXTRA_EXTRA).isEmpty()) {
                    TLog.i(TAG, "This message has no Extra data");
                    continue;
                }

                try {
                    JSONObject json = new JSONObject(bundle.getString(JPushInterface.EXTRA_EXTRA));
                    Iterator<String> it = json.keys();

                    while (it.hasNext()) {
                        String myKey = it.next().toString();
                        sb.append("\nkey:" + key + ", value: [" +
                                myKey + " - " + json.optString(myKey) + "]");
                    }
                } catch (JSONException e) {
                    TLog.e(TAG, "Get message extra JSON error!");
                }

            } else {
                sb.append("\nkey:" + key + ", value:" + bundle.getString(key));
            }
        }
        return sb.toString();
    }


}
