package com.mints.goodmoney.ui.activitys

import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.CompoundButton
import androidx.recyclerview.widget.GridLayoutManager
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.login.LoginApi
import com.mints.goodmoney.login.OnLoginListener
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.DrawcashBean
import com.mints.goodmoney.mvp.model.WXInfo
import com.mints.goodmoney.mvp.presenters.DrawcashPresenter
import com.mints.goodmoney.mvp.views.DrawcashView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.DrawcashAdapter
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener
import com.mints.goodmoney.ui.widgets.DrawcashVideoDialog
import com.mints.goodmoney.ui.widgets.JDTintDialog
import com.mints.goodmoney.utils.LogUtil
import com.mints.library.utils.CommonUtils
import com.mints.library.utils.json.JsonUtil
import kotlinx.android.synthetic.main.activity_drawcash.*
import kotlinx.android.synthetic.main.header_layout.*
import kotlinx.android.synthetic.main.view_title.*
import java.math.BigDecimal
import java.util.*

/**
 * 描述：提现
 * 作者：孟崔广
 * 时间：2020/10/12 14:37
 */
class DrawcashActivity : BaseActivity(),
        DrawcashView, View.OnClickListener, OnItemClickListener, OnLoginListener, CompoundButton.OnCheckedChangeListener {

    private val TAG = DrawcashActivity::class.java.simpleName

    private var drawcashVideoDialog: DrawcashVideoDialog? = null

    private lateinit var vedioAdingManager: VideoAdingManager
    private val drawcashPresenter by lazy { DrawcashPresenter() }
    private lateinit var drawcashAdapter: DrawcashAdapter
    private val userManager by lazy { UserManager.getInstance() }
    private val loginApi by lazy { LoginApi() }

    private var priceList: MutableList<DrawcashBean.CashOutMoneyArrBean>? = null
    private var wxInfo: WXInfo? = null
    private var userConfig: DrawcashBean? = null
    private var isLoadRvItem: Boolean = true //是否首次加载rv item

    //    private var isJDNewUser = false
//    private var jumpJdUrl: String? = null
    private var jdTintDialog: JDTintDialog? = null

    override fun getContentViewLayoutID() = R.layout.activity_drawcash

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        tv_title.text = "提现"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)
        tv_right_subtitle.visibility = View.VISIBLE
        tv_right_subtitle.text = "提现记录"
        tvDrawWechat.isChecked = true
        tvDrawJd.setOnCheckedChangeListener(this)

        view_title.text = "提现规则"
        vedioAdingManager = VideoAdingManager.getInstance(this)
        drawcashPresenter.attachView(this)
        initListener()
    }

    override fun onResume() {
        super.onResume()

        drawcashPresenter.getUserTaskMsg()
    }

    override fun onDestroy() {
        super.onDestroy()

        loginApi.setOnLoginListener(null)
        drawcashVideoDialog?.setOnClickListener(null)
        drawcashVideoDialog?.onDestory()

        drawcashPresenter.detachView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_right_subtitle -> {
                // 是否登录
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                readyGo(DrawcashRecordActivity::class.java)
            }
            R.id.tvDrawcashWx -> {
                // 是否登录
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                if (!TextUtils.isEmpty(userConfig?.openid)) {
                    return
                }

                val wechat = ShareSDK.getPlatform(Wechat.NAME)
                if (!wechat.isClientValid) {
                    showToast("请先安装微信")
                    return
                }

                loginApi.setOnLoginListener(this)
                loginApi.setPlatform(Wechat.NAME)
                loginApi.login(this)
            }
            R.id.tvDrawcashNext -> {
                if (priceList != null && priceList!!.size > 0) {
                    // 跳转京东金融
//                    if (isJDNewUser) {
//                        jumpJdUrl?.let {
//                            val bundle = Bundle()
//                            bundle.putString(WebActivity.WEB_TITLE, "京东金融")
//                            bundle.putString(WebActivity.WEB_URL, jumpJdUrl)
//                            readyGo(WebActivity::class.java, bundle)
//                            return
//                        }
//                    }

                    // 校验当前金币< 选择金币 =提示 去做任务
                    if (userConfig?.coin!! < priceList!![drawcashAdapter.getPosition()].money * 10000) {
                        showToast("金币不足，快去做任务吧")
                        return
                    }

                    // 是否登录
                    if (!userManager.userIsLogin()) {
                        readyGo(WxLoginActivity::class.java)
                        return
                    }

                    // 是否绑定手机号
                    if (TextUtils.isEmpty(userManager.mobile)) {
                        readyGo(BindMobileActivity::class.java)
                        return
                    }

                    // 授权判断
                    if (TextUtils.isEmpty(userConfig?.openid)) {
                        showToast("微信未授权")
                        return
                    }

                    // 可提金额
                    if (priceList!![drawcashAdapter.getPosition()].money > userConfig?.maxCashout!!) {
                        showToast("请先提现${userConfig?.maxCashout}元")
                        return
                    }

                    val curCount = userConfig?.vedioComplete!!
                    val sumCount = priceList!![drawcashAdapter.getPosition()].vedio
                    if (curCount >= sumCount) {
                        drawcashPresenter.saveTerminalInfo(priceList!![drawcashAdapter.getPosition()].money)
                    } else {
                        drawcashVideoDialog(curCount, sumCount)
                    }
                }
            }
        }
    }

    override fun getUserTaskMsgSuc(data: DrawcashBean) {
        userConfig = data
        tvDrawcashExplain.text = data.drawcashRule
        tvDrawcashHint.text = data.drawcashHint
        tvDrawcashGold.text = CommonUtils.formatString(data.coin.toString())
        if (TextUtils.isEmpty(data.openid)) {
            tvDrawcashWx.setText("去授权")
            tvDrawcashName.setText("微信昵称")
        } else {
            tvDrawcashWx.setText("已授权")
            tvDrawcashName.setText(data.nickName)
        }

//        if (data.isJDNewUser) {
//            jumpJdUrl = data.jdUrl
//            isJDNewUser = true
//            rl_drawcash.visibility = View.VISIBLE
//            rl_drawcash.setOnCheckedChangeListener(this)
//        } else {
//            rl_drawcash.visibility = View.GONE
//        }

        if (data.isOpenJDCash) {
            rl_drawcash.visibility = View.VISIBLE
        } else {
            rl_drawcash.visibility = View.GONE
        }

        // 提现更改权重
        initAdWeight(data.vedioRules)

        // 修改提现弹窗内容
        if (drawcashVideoDialog != null && drawcashVideoDialog!!.isShowing) {
            drawcashVideoDialog?.setContent("下载并打开体验后可立即提现（${data.vedioComplete}/${data.cashOutMoneyArr[drawcashAdapter.getPosition()].vedio}）")
            if (data.vedioComplete >= data.cashOutMoneyArr[drawcashAdapter.getPosition()].vedio) {
                drawcashVideoDialog?.setBtnText("去提现")
            } else {
                drawcashVideoDialog?.setBtnText("去观看")
            }
        }

        if (isLoadRvItem) {
            priceList = data.cashOutMoneyArr
            initRvView()
        }
        val allcoinBig = BigDecimal(data.coin.toString())
        val rateBig = BigDecimal("10000")
        val cashStr: String = allcoinBig.divide(rateBig).setScale(2, BigDecimal.ROUND_DOWN).toString()
        tvDrawcashGoldabout.setText("约" + cashStr + "元")
    }

    override fun editUserMsgSuc() {
        showToast("微信授权成功")

        drawcashPresenter.getUserTaskMsg()
    }

    override fun mergeAccount(mobile: String, wxOpenId: String, key: String) {
        val bundle = Bundle()
        bundle.putString(Constant.MERGE_MOBILE, mobile)
        bundle.putString(Constant.MERGE_WXOPENID, wxOpenId)
        bundle.putString(Constant.MERGE_KEY, key)
        readyGo(AccountMergeActivity::class.java, bundle)
    }

    override fun onLogin(platform: String?, res: HashMap<String, Any>): Boolean {
        try {
            wxInfo = WXInfo()
            wxInfo?.let {
                it.setUnionid(res["unionid"].toString() + "")
                it.setOpenid(res["openid"].toString() + "")
                it.setProvince(res["province"].toString() + "")
                it.setCity(res["city"].toString() + "")
                it.setCountry(res["country"].toString() + "")
                it.setHeadimgurl(res["headimgurl"].toString() + "")
                it.setNickname(res["nickname"].toString() + "")
                it.setSex((res["sex"].toString() + "").toInt())
            }

            if (!isFinishing) {
                drawcashPresenter.editUserMsg(res["openid"].toString(), JsonUtil.toJson(wxInfo))
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return false
    }

    private fun initRvView() {
        val gridLayoutManager = GridLayoutManager(this, 3)
        rvCash.layoutManager = gridLayoutManager
        drawcashAdapter = priceList?.let {
            DrawcashAdapter(it, userConfig?.remark!!)
        }!!
        rvCash.adapter = drawcashAdapter
        drawcashAdapter.setOnItemClickListener(this)

        isLoadRvItem = false
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_right_subtitle.setOnClickListener(this)
        tvDrawcashWx.setOnClickListener(this)
        tvDrawcashNext.setOnClickListener(this)
    }

    override fun onItemClick(view: View?, position: Int) {
        drawcashAdapter.setPosition(position)
        drawcashAdapter.notifyDataSetChanged()
    }

    /**
     * 设置视频权重
     */
    private fun initAdWeight(data: DrawcashBean.VedioRules) {
        vedioAdingManager.initAdWeight(data.csJ_VEDIO,
                data.ylH_VEDIO,
                data.sdhZ_VEDIO,
                data.fL_VEDIO,
                data.coraL_VEDIO,
                data.csjfulL_VEDIO)
        LogUtil.d(TAG, "提现权重值：csjWeight:${data.csJ_VEDIO}    " +
                "ylhWeight:${data.ylH_VEDIO}    " +
                "sdhzWeight:${data.sdhZ_VEDIO}    " +
                "csjFullWeight:${data.csjfulL_VEDIO}    " +
                "shWeight:${data.coraL_VEDIO}    " +
                "flWeight:${data.fL_VEDIO}")
        // 广告视频数
        AppConfig.csjVideoAdCount = 10
        AppConfig.ylhAdCount = 10
        AppConfig.wnVideoAdCount = 10
        AppConfig.flVideoAdCount = 10
        AppConfig.shVideoAdCount = 10
        AppConfig.csjFullVedioAdCount = 10
    }

    /**
     * 提现看视频
     */
    private fun drawcashVideoDialog(curCount: Int, sumCount: Int) {
        if (drawcashVideoDialog == null) {
            drawcashVideoDialog = DrawcashVideoDialog(this)
        }
        drawcashVideoDialog?.let {
            if (sumCount == 1) {
                it.setContent("下载并打开体验后可立即提现")
            } else {
                it.setContent("下载并打开体验后可立即提现（${curCount}/${sumCount}）")
            }
            it.setOnClickListener(object : DrawcashVideoDialog.OnClickListener {
                override fun onClick() {
                    if (priceList != null && priceList!!.size > 0) {
                        drawcashPresenter.saveTerminalInfo(priceList!![drawcashAdapter.getPosition()].money)
                    }
                }
            })
            it.show()
        }
    }

    override fun checkJDNewUsersSuc(isJdNewUser: Boolean, JDUrl: String?) {
        jdTintDialog?.dismiss()

        if (isJdNewUser) {
            JDUrl?.let {
                val bundle = Bundle()
                bundle.putString(WebActivity.WEB_TITLE, "京东金融")
                bundle.putString(WebActivity.WEB_URL, it)
                readyGo(WebActivity::class.java, bundle)
                return
            }
        }

        showToast("手机号已注册京东金融")
    }

    override fun checkJDNewUsersFail() {
        jdTintDialog?.dismiss()

        showToast("手机号已注册京东金融")
    }

    override fun getCommonJdUrlSuc(JDUrl: String?) {
        JDUrl?.let {
            val bundle = Bundle()
            bundle.putString(WebActivity.WEB_TITLE, "京东金融")
            bundle.putString(WebActivity.WEB_URL, it)
            readyGo(WebActivity::class.java, bundle)
            return
        }
    }

    override fun onCheckedChanged(buttonView: CompoundButton, isChecked: Boolean) {
        if (buttonView.isChecked) {
            tvDrawJd.isChecked = false
            tvDrawWechat.isChecked = true

            drawcashPresenter.getCommonJdUrl()

//            tvDrawWechat.isChecked = false

//            jdTintDialog = JDTintDialog(this, object : DialogListener() {
//                override fun onClick(v: View?) {
//                    when (v?.id) {
//                        R.id.ivClose -> {
//                            jdTintDialog?.dismiss()
//                            tvDrawJd.isChecked = false
//                            tvDrawWechat.isChecked = true
//                        }
//                        R.id.btnBindMobile -> {
//                            if (jdTintDialog?.getMobileNum()!!.length < 11) {
//                                showToast("请输入手机号")
//                                return
//                            }
//                            val mobileNum = jdTintDialog?.getMobileNum()!!.replace(" ".toRegex(), "")
//                            jdTintDialog?.dismiss()
//                            tvDrawJd.isChecked = false
//                            tvDrawWechat.isChecked = true
//
//                            drawcashPresenter.checkJDNewUsers(mobileNum)
//                        }
//                    }
//
//                }
//
//            })
//            jdTintDialog?.show()
        }
    }
}