package com.mints.goodmoney.ui.activitys

import android.view.View
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager.widget.ViewPager
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.FriendHallMsgBean
import com.mints.goodmoney.mvp.presenters.FriendsActivityPresenter
import com.mints.goodmoney.mvp.views.FriendsActivityView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.FriendsInvitedAdapter
import com.mints.goodmoney.ui.adapter.FriendsPagerAdapter
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.fragment_main_friends.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：亲友团详情
 * 作者：孟崔广
 * 时间：2020/9/20 17:30
 */
class FriendsActivity : BaseActivity(), View.OnClickListener, FriendsActivityView, OnRefreshListener {

    private val friendsActivityPresenter by lazy { FriendsActivityPresenter() }

    private var viewPagerAdapter: FriendsPagerAdapter? = null

    private val recyList: MutableList<RecyclerView> = mutableListOf()

    private var directData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var indirectData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()

    private var directAdapter: FriendsInvitedAdapter? = null
    private var indirectAdapter: FriendsInvitedAdapter? = null

    override fun getContentViewLayoutID() = R.layout.activity_friends

    override fun initViewsAndEvents() {
        tv_title.text = "亲友团详情"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        friendsActivityPresenter.attachView(this)

        initListener()
        initRecy()

        friendsActivityPresenter.getDirectFriends()
    }

    private fun initRecy() {
        val recyFriends = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        val recyWorld = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        recyFriends.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))
        recyWorld.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))

        directAdapter = FriendsInvitedAdapter(mContext, directData)
        indirectAdapter = FriendsInvitedAdapter(mContext, indirectData)

        recyFriends.adapter = directAdapter
        recyWorld.adapter = indirectAdapter

        recyList.add(recyFriends)
        recyList.add(recyWorld)

        val titleList = arrayListOf("直接亲友", "间接亲友")
        viewPagerAdapter = FriendsPagerAdapter(titleList, recyList)
        view_pager_friends.adapter = viewPagerAdapter
        view_pager_friends.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
            override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {
            }

            override fun onPageSelected(position: Int) {
                if (position == 0) {
                    if (directData.size <= 0) {
                        friendsActivityPresenter.getDirectFriends()
                    }
                } else {
                    if (indirectData.size <= 0) {
                        friendsActivityPresenter.getIndirectFriends()
                    }
                }
            }

            override fun onPageScrollStateChanged(state: Int) {
            }

        })

        tab_friends.setupWithViewPager(view_pager_friends)
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> finish()
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        friendsActivityPresenter.detachView()
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        srl_my.setOnRefreshListener(this)
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onDirectFriendsSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        directData.clear()
        directData.addAll(data.list)
        directAdapter?.notifyDataSetChanged()
    }

    override fun onIndirectFriendsSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        indirectData.clear()
        indirectData.addAll(data.list)
        indirectAdapter?.notifyDataSetChanged()
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        if (UserManager.getInstance().userID.isNotEmpty()) {
            if (view_pager_friends.currentItem == 0) {
                friendsActivityPresenter.getDirectFriends()
            } else {
                friendsActivityPresenter.getIndirectFriends()
            }
        }
    }
}