package com.mints.goodmoney.ui.activitys

import android.Manifest
import android.media.MediaPlayer
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import com.downloader.Error
import com.downloader.OnDownloadListener
import com.downloader.PRDownloader
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.call.business.VideoDBHelper
import com.mints.goodmoney.call.detail.DetailApplyActivity
import com.mints.goodmoney.call.permission.PermissionActivity
import com.mints.goodmoney.call.permission.PermissionManager
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.VideoAdingBean
import com.mints.goodmoney.mvp.presenters.KylVideoPresenter
import com.mints.goodmoney.mvp.views.KylVideoView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.MD5
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.activity_kyl_video.*

/**
 * 描述：酷音乐视频
 * 作者：孟崔广
 * 时间：2021/1/4 15:09
 */
class KylVideoActivity : BaseActivity(), View.OnClickListener, KylVideoView {

    companion object {
        const val VIDEO_URL = "video_url"
    }

    private lateinit var videoUrl: String

    private val kylVideoPresenter by lazy { KylVideoPresenter() }
    private lateinit var videoAdingManager: VideoAdingManager
    private var loadVideoFailCount = 0

    private var downloadId: Int = -1//vedio下载id
    private var downloadVedioSucFlag = false// 下载视频成功
    private var vedioPathName = ""

    override fun getContentViewLayoutID() = R.layout.activity_kyl_video

    override fun isApplyKitKatTranslucency() = false

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            videoUrl = it.getString(VIDEO_URL, "")
        }
    }

    override fun initViewsAndEvents() {
        if (TextUtils.isEmpty(videoUrl)) {
            showToast("加载失败，请稍后重试.")
            finish()
            return
        }
        videoAdingManager = VideoAdingManager.getInstance(this)
        initListener()
        loadVedio(videoUrl)
    }

    private fun loadVedio(vedioUrl: String) {
        cvvVedio.setOnPreparedListener { mp: MediaPlayer ->
            mp.start()
            mp.isLooping = true
        }
        cvvVedio?.setVideoPath(vedioUrl)
        cvvVedio?.start()
    }

    override fun onResume() {
        super.onResume()

        cvvVedio.resume()
    }

    override fun onPause() {
        super.onPause()

        cvvVedio.pause()
    }

    override fun onDestroy() {
        super.onDestroy()
        if (downloadId != -1) {
            PRDownloader.cancel(downloadId)
        }
        videoAdingManager.setVideoAdingListener(null)
        videoAdingManager.onDestory()
        kylVideoPresenter.detachView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.ivBack -> finish()
            R.id.ivSetting -> {
                if (downloadVedioSucFlag) {
                    readyGo()
                    return
                }
                RxPermissions(this)
                        .request(Manifest.permission.READ_EXTERNAL_STORAGE, Manifest.permission.WRITE_EXTERNAL_STORAGE)
                        .subscribe { granted: Boolean ->
                            if (granted) {
                                downloadVedioToCacheFile()
                                awardVideo()
                            } else {
                                showMissingPermissionDialog("存储")
                            }
                        }
            }
        }
    }

    private fun downloadVedioToCacheFile() {
        downloadVedioSucFlag = false
        var vedioPath = ""
        try {
            vedioPath = getExternalFilesDir(null)!!.absolutePath + "/video/"
        } catch (e: java.lang.Exception) {
            vedioPath = filesDir.absolutePath + "/video/"
        }
        val vedioName = MD5.GetMD5Code(System.currentTimeMillis().toString() + UserManager.getInstance().userID + videoUrl) + ".mp4"
        vedioPathName = vedioPath + vedioName
        downloadId = PRDownloader.download(videoUrl, vedioPath, vedioName)
                .build()
                .start(object : OnDownloadListener {
                    override fun onDownloadComplete() {
                        downloadVedioSucFlag = true
                    }

                    override fun onError(error: Error) {
                    }
                })
    }

    private fun initListener() {
        ivBack.setOnClickListener(this)
        ivSetting.setOnClickListener(this)
    }

    /**
     * 获取激励视频
     */
    private fun awardVideo() {
        if (videoAdingManager.videoFinishFlag) {
            showToast("今日视频已看完，请明天再来吧")
            return
        }
        loadVideoFailCount = 0
        showLoading("加载中...")

        val bean = VideoAdingBean()
        bean.carrierType = Constant.CARRIER_KUYINYUE_VEDIO
        loadVideo(videoAdingManager, bean, true)
    }

    /**
     * 加载激励视频
     */
    private fun loadVideo(videoAdingManager: VideoAdingManager, bean: VideoAdingBean, isFirstLoad: Boolean) {
        videoAdingManager.setVideoAdingListener(object : VideoAdingManager.VideoAdingListener {
            override fun videoAdingListenerError(adType: String) {
                showToast("加载超时，请休息一下")
                hideLoading()
            }

            override fun videoAdingListenerFail(adType: String) {
                loadVideoFailCount++
                if (loadVideoFailCount >= 2) {
                    hideLoading()
                    showToast("加载失败，请稍后重试!")
                } else {
                    loadVideo(videoAdingManager, bean, false)
                }
            }

            override fun videoAdingListenerSuccess(adType: String) {
                hideLoading()
                vedioAdingSuccess(adType)
            }
        })
        if (isFirstLoad) {
            // 首页按权重加载
            videoAdingManager.loadAding(this, bean)
        } else {
            // 失败按优先级加载
            videoAdingManager.loadFailAding(this, bean)
        }
    }

    private fun vedioAdingSuccess(adType: String) {
        if (!downloadVedioSucFlag || TextUtils.isEmpty(vedioPathName)) {
            showToast("视频处理中，请稍候")
            return
        }

//        DetailActivity.startSelf(this@KylVideoActivity, vedioPathName)
//        finish()
        readyGo()
    }

    private fun readyGo() {
        if (PermissionManager.getInstance().checkEssential(this)) {
            VideoDBHelper.getInstance().setSelectVideo(this, VideoDBHelper.UNKNOWN_NUMBER, vedioPathName)
            DetailApplyActivity.startSelf(this, vedioPathName, true)
        } else {
            PermissionActivity.startSelf(this)
        }
    }
}
