package com.mints.goodmoney.ui.activitys

import android.Manifest
import android.text.TextUtils
import android.view.View
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.*
import com.mints.goodmoney.mvp.presenters.LoginPresenter
import com.mints.goodmoney.mvp.views.LoginView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.BackInputUtil
import com.mints.goodmoney.utils.LogUtil
import com.mints.library.utils.nodoubleclick.AntiShake
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.activity_bind_mobile.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：手机号登录
 * 作者：孟崔广
 * 时间：2020/12/2 14:21
 */
class MobileLoginActivity : BaseActivity(), LoginView, View.OnClickListener {

    private val loginPresenter by lazy { LoginPresenter() }

    private var mobile: String? = null

    override fun initViewsAndEvents() {
        loginPresenter.attachView(this)
        initView()
        initListener()
    }

    override fun getContentViewLayoutID() = R.layout.activity_mobile_login

    override fun isApplyKitKatTranslucency() = false

    override fun onDestroy() {
        super.onDestroy()
        loginPresenter.detachView()
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> {
                finish()
            }
            R.id.tvLoginSendcode -> {
                var mobile = etLoginMobile.text.toString().trim()
                if (mobile.length < 13) {
                    showToast("请输入手机号")
                    return
                }
//                sendCodeThread()

                mobile = mobile.replace(" ".toRegex(), "")
                loginPresenter.sendMobileCode(mobile)
            }
            R.id.tvLoginNext -> {
                var mobile = etLoginMobile.text.toString().trim()
                if (mobile.length < 13) {
                    showToast("请输入手机号")
                    return
                }

                val code = etLoginCode.text.toString().trim()
                if (code.length < 4) {
                    showToast("请输入验证码")
                    return
                }


                RxPermissions(this@MobileLoginActivity)
                        .request(Manifest.permission.READ_PHONE_STATE)
                        .subscribe { granted: Boolean ->
                            if (granted) {

                                mobile = mobile.replace(" ".toRegex(), "")
                                // 登录
                                loginPresenter.login(mobile, code)
                            } else {
                                showMissingPermissionDialog("设备")
                            }
                        }
            }
        }
    }

    override fun loginSuc() {
        try {
            // 登录成功初始化鱼玩盒子userid
            YwhzManager.init(baseApplication)
        } catch (e: Exception) {
        }

        // 每日任务是否刷新任务数
        TrackManager.getInstance().innerApp()

        SceneManager.signIn(this)
        RsNewsManager.init(baseApplication)
        BxmManager.bindUserData()

        // false-登录  true-绑定手机号
        showToast("登录成功")

        progressDialog?.dismiss()

        readyGo(MainActivity::class.java)
    }

    override fun sendCodeSuc() {
        if (!isFinishing) {
            sendCodeThread()
        }
    }

    override fun mergeAccount(mobile: String, wxOpenId: String, key: String) {

    }

    private fun initView() {
        tv_title.text = "手机号登录"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        BackInputUtil.phoneNumAddSpace(etLoginMobile)
        mobile = UserManager.getInstance().mobile
        if (!TextUtils.isEmpty(mobile)) {
            etLoginMobile.setText(mobile)
            etLoginMobile.setSelection(mobile!!.length + 2)
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tvLoginSendcode.setOnClickListener(this)
        tvLoginNext.setOnClickListener(this)
    }

    var num = 0
    var run: Runnable? = null

    fun sendCodeThread() {
        num = 60
        tvLoginSendcode?.let {
            it.isEnabled = false
            it.text = "（$num）重新获取"

            run = object : Runnable {
                override fun run() {
                    num--
                    LogUtil.d("login", "login num:$num")
                    if (num == 0) {
                        it.text = "重新获取"
                        it.isEnabled = true
                    } else {
                        it.text = "（$num）重新获取"
                        it.postDelayed(this, 1000)
                    }
                }
            }
            it.postDelayed(run, 1000)
        }
    }
}
