package com.mints.goodmoney.ui.activitys.base;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.ActivityInfo;
import android.os.Build;
import android.os.Bundle;

import androidx.core.content.ContextCompat;

import android.text.TextUtils;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.R;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.mvp.views.BaseView;
import com.mints.goodmoney.ui.widgets.LoadingDialog;
import com.mints.goodmoney.utils.StatusBarUtil;
import com.mints.goodmoney.utils.ToastUtil;
import com.mints.library.base.BaseAppCompatActivity;
import com.mints.library.net.netstatus.NetUtils;


public abstract class BaseActivity extends BaseAppCompatActivity implements BaseView {

    protected LoadingDialog progressDialog;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (android.os.Build.VERSION.SDK_INT != Build.VERSION_CODES.O) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }

        try {
            if (TextUtils.equals(getClass().getSimpleName(), "SplashActivity") ||
                    TextUtils.equals(getClass().getSimpleName(), "GuideActivity")) {
                getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,
                        WindowManager.LayoutParams.FLAG_FULLSCREEN);
            } else {
                StatusBarUtil.transparencyBar(this); //设置状态栏全透明
                StatusBarUtil.StatusBarLightMode(this); //设置白底黑字
            }
        } catch (Exception e) {
            e.printStackTrace();
        }


        if (isApplyKitKatTranslucency()) {
            setSystemBarTintDrawable(ContextCompat.getDrawable(getContext(), R.drawable.sr_primary));
        }

        registerExitApp();
    }

    @Override
    public MintsApplication getBaseApplication() {
        return (MintsApplication) getApplication();
    }

    public Context getContext() {
        return this;
    }

    @Override
    protected void onDestroy() {
        unRegisterExitApp();
        super.onDestroy();
    }

    /**
     * 如果需要在前台做断网判断则需要重写
     */
    @Override
    protected void onNetworkDisConnected() {
        showToast(getString(R.string.netfail));
    }

    @Override
    protected boolean isApplyStatusBarTranslucency() {
        return true;
    }

    @Override
    protected void getBundleExtras(Bundle extras) {
    }

    @Override
    protected View getLoadingTargetView() {
        return null;
    }

    @Override
    protected void onNetworkConnected(NetUtils.NetType type) {

    }

    @Override
    protected boolean toggleOverridePendingTransition() {
        return false;
    }

    @Override
    protected TransitionMode getOverridePendingTransitionMode() {
        return null;
    }

    @Override
    protected boolean toggleIsBack2Left() {
        return false;
    }

    /**
     * 显示加载进度条（自定义message）
     *
     * @param message
     */
    @Override
    public void showLoading(String message) {
        if (this.getWindow() != null && !this.isFinishing()) {
            if (progressDialog == null) {
                progressDialog = new LoadingDialog(this);
                progressDialog.setLoadText(message);
            }

            progressDialog.show();
            setProgressOnTouchOutside(false);
            setProgressNoDismiss();
        }
    }

    /**
     * 设置Progress是否手触消失
     *
     * @param onTouchOutside
     */
    public void setProgressOnTouchOutside(boolean onTouchOutside) {
        if (progressDialog != null)
            progressDialog.setCanceledOnTouchOutside(onTouchOutside);
    }

    /**
     * 设置点击返回是否消失加载进度条
     */
    public final void setProgressNoDismiss() {
        if (progressDialog != null && progressDialog.isShowing()) {
            progressDialog.setOnKeyListener(new DialogInterface.OnKeyListener() {

                @Override
                public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event) {
                    if (keyCode == KeyEvent.KEYCODE_BACK) {
                        return true;
                    }
                    return false;
                }
            });
        }
    }

    /**
     * 消失加载进度条
     */
    @Override
    public void hideLoading() {
        try {
            if (this.getWindow() != null && !this.isFinishing()) {
                if (progressDialog != null && progressDialog.isShowing()) {
                    progressDialog.dismiss();
                    progressDialog = null;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            progressDialog = null;
        }
    }

    protected abstract boolean isApplyKitKatTranslucency();

    /**
     * 弹出系统的Toast
     */
    @Override
    public void showToast(String msg) {
        if (!TextUtils.isEmpty(msg))
            ToastUtil.show(MintsApplication.getContext(), msg);
    }

    /**
     * 注册退出app本地广播
     */
    private void registerExitApp() {
        IntentFilter filter = new IntentFilter();
        filter.addAction(Constant.ACTION_EXIT_APP);
        filter.addCategory(Intent.CATEGORY_DEFAULT);
        MintsApplication.getLocalBroadcastManager().registerReceiver(mExitReceiver, filter);
    }

    private BroadcastReceiver mExitReceiver = new BroadcastReceiver() {

        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (action.equals(Constant.ACTION_EXIT_APP)) {
                finish();
            }
        }
    };

    /**
     * 注销退出app本地广播
     */
    private void unRegisterExitApp() {
        IntentFilter filter = new IntentFilter();
        filter.addAction(Constant.ACTION_EXIT_APP);
        filter.addCategory(Intent.CATEGORY_DEFAULT);
        MintsApplication.getLocalBroadcastManager().unregisterReceiver(mExitReceiver);
    }

}
