package com.mints.goodmoney.ui.adapter

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.bytedance.sdk.openadsdk.*
import com.bytedance.sdk.openadsdk.TTAdDislike.DislikeInteractionCallback
import com.mints.goodmoney.R
import com.mints.goodmoney.mvp.model.KylBean
import com.mints.library.utils.GlideUtils
import com.shehuan.niv.NiceImageView
import java.util.*

class KylPageAdapter(val kylPageList: MutableList<KylBean.Data>) :
        RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private var mTTAppDownloadListenerMap: WeakHashMap<CsjAdHolder, TTAppDownloadListener> = WeakHashMap<CsjAdHolder, TTAppDownloadListener>()

    companion object {
        const val HOLDER_TYPE_KYL = 0
        const val HOLDER_TYPE_CSJAD = 0
    }

    lateinit var context: Context

    lateinit var mOnItemClickListener: OnItemClickListener

    inner class ViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val ivKylPage: NiceImageView = view.findViewById(R.id.ivKylPage)
        val tvKylPageContent: TextView = view.findViewById(R.id.tvKylPageContent)
    }

    inner class CsjAdHolder(view: View) : RecyclerView.ViewHolder(view) {
        val mTitle: TextView = view.findViewById(R.id.tv_listitem_ad_title)
        val mCreativeButton: Button = view.findViewById(R.id.btn_listitem_creative)
        val mSource: TextView = view.findViewById(R.id.tv_listitem_ad_source)
        val mIcon: ImageView = view.findViewById(R.id.iv_listitem_icon)
        val iv_listitem_dislike: ImageView = view.findViewById(R.id.iv_listitem_dislike)
        val btn_listitem_creative: Button = view.findViewById(R.id.btn_listitem_creative)
        val ivKylPage: NiceImageView = view.findViewById(R.id.ivKylPage)
        val tvKylPageContent: TextView = view.findViewById(R.id.tvKylPageContent)
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        context = parent.context

        if (viewType == HOLDER_TYPE_KYL) {
            val view = LayoutInflater.from(context).inflate(R.layout.item_rv_kyl_page, parent, false)
            return ViewHolder(view)
        }

        val view = LayoutInflater.from(context).inflate(R.layout.item_rv_csj_page, parent, false)
        return CsjAdHolder(view)
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val data = kylPageList[position]
        if (holder is ViewHolder) {
            holder.tvKylPageContent.text = data.nm
            GlideUtils.loadImageView(holder.itemView.context, data.pvurl, holder.ivKylPage)

            holder.itemView.setOnClickListener {
                if (::mOnItemClickListener.isInitialized) {
                    mOnItemClickListener.onItemClick(position)
                }
            }
        } else if (holder is CsjAdHolder) {
            val adBean = data.adBean!!
            holder.tvKylPageContent.text = adBean?.description
            val images = ArrayList<View>()
            images.add(holder.ivKylPage)
            bindData(holder, images, adBean)
            if (adBean.getImageList() != null && !adBean.getImageList().isEmpty()) {
                val image: TTImage = adBean.getImageList().get(0)
                if (image != null && image.isValid) {
                    GlideUtils.loadImageView(holder.itemView.context, image.imageUrl, holder.ivKylPage)
                }
            }
        }
    }

    override fun getItemCount() = kylPageList.size

    override fun getItemViewType(position: Int): Int {
        if (kylPageList[position].adBean == null) {
            return HOLDER_TYPE_KYL
        }
        return HOLDER_TYPE_CSJAD
    }

    interface OnItemClickListener {
        fun onItemClick(position: Int)
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

    private fun bindData(adViewHolder: CsjAdHolder, images: List<View>, ad: TTFeedAd) {
        //设置dislike弹窗，这里展示自定义的dialog
        bindDislikeCustom(adViewHolder.iv_listitem_dislike, ad)
        //可以被点击的view, 也可以把convertView放进来意味item可被点击
        val clickViewList: MutableList<View> = ArrayList()
        clickViewList.add(adViewHolder.itemView)
        //触发创意广告的view（点击下载或拨打电话）
        val creativeViewList: MutableList<View> = ArrayList()
        creativeViewList.add(adViewHolder.btn_listitem_creative)
        //如果需要点击图文区域也能进行下载或者拨打电话动作，请将图文区域的view传入
//            creativeViewList.add(convertView);
        //重要! 这个涉及到广告计费，必须正确调用。convertView必须使用ViewGroup。
        ad.registerViewForInteraction((adViewHolder.itemView as ViewGroup), images, clickViewList, creativeViewList, adViewHolder.iv_listitem_dislike, object : TTNativeAd.AdInteractionListener {
            override fun onAdClicked(view: View, ad: TTNativeAd) {
            }

            override fun onAdCreativeClick(view: View, ad: TTNativeAd) {
            }

            override fun onAdShow(ad: TTNativeAd) {
            }
        })
        adViewHolder.mTitle.setText(ad.title)
        adViewHolder.tvKylPageContent.setText(ad.description)
        adViewHolder.mSource.setText(if (ad.source == null) "广告来源" else ad.source)
        val icon = ad.icon
        if (icon != null && icon.isValid) {
            GlideUtils.loadImageView(context, icon.imageUrl, adViewHolder.mIcon)
            val adCreativeButton: Button = adViewHolder.mCreativeButton
            when (ad.interactionType) {
                TTAdConstant.INTERACTION_TYPE_DOWNLOAD -> {
                    //如果初始化ttAdManager.createAdNative(getApplicationContext())没有传入activity 则需要在此传activity，否则影响使用Dislike逻辑
                    if (context is Activity) {
                        ad.setActivityForDownloadApp((context as Activity?)!!)
                    }
                    adCreativeButton.visibility = View.VISIBLE
//                adViewHolder.mStopButton.setVisibility(View.VISIBLE)
//                adViewHolder.mRemoveButton.setVisibility(View.VISIBLE)
                    bindDownloadListener(adCreativeButton, adViewHolder, ad)
                    //绑定下载状态控制器
                    bindDownLoadStatusController(adViewHolder, ad)
                }
                TTAdConstant.INTERACTION_TYPE_DIAL -> {
                    adCreativeButton.visibility = View.VISIBLE
                    adCreativeButton.text = "立即拨打"
//                adViewHolder.mStopButton.setVisibility(View.GONE)
//                adViewHolder.mRemoveButton.setVisibility(View.GONE)
                }
                TTAdConstant.INTERACTION_TYPE_LANDING_PAGE, TTAdConstant.INTERACTION_TYPE_BROWSER -> {
                    adCreativeButton.visibility = View.VISIBLE
                    adCreativeButton.text = "查看详情"
//                adViewHolder.mStopButton.setVisibility(View.GONE)
//                adViewHolder.mRemoveButton.setVisibility(View.GONE)
                }
                else -> {
                    adCreativeButton.visibility = View.GONE
//                adViewHolder.mStopButton.setVisibility(View.GONE)
//                adViewHolder.mRemoveButton.setVisibility(View.GONE)
                }
            }
        }
    }

    private fun bindDislikeCustom(dislike: View, ad: TTFeedAd) {
        val ttAdDislike = ad.getDislikeDialog(context as Activity?)
        if (ttAdDislike != null) {
            ad.getDislikeDialog(context as Activity?).setDislikeInteractionCallback(object : DislikeInteractionCallback {
                override fun onSelected(position: Int, value: String) {
                }
                override fun onCancel() {}
                override fun onRefuse() {}
            })
        }
        dislike.setOnClickListener { ttAdDislike!!.showDislikeDialog() }
    }

    private fun bindDownloadListener(adCreativeButton: Button, adViewHolder: CsjAdHolder, ad: TTFeedAd) {
        val downloadListener: TTAppDownloadListener = object : TTAppDownloadListener {
            override fun onIdle() {
                if (!isValid) {
                    return
                }
                adCreativeButton.text = "开始下载"
//                adViewHolder.mStopButton.setText("开始下载")
            }

            @SuppressLint("SetTextI18n")
            override fun onDownloadActive(totalBytes: Long, currBytes: Long, fileName: String, appName: String) {
                if (!isValid) {
                    return
                }
                if (totalBytes <= 0L) {
                    adCreativeButton.text = "0%"
                } else {
                    adCreativeButton.text = (currBytes * 100 / totalBytes).toString() + "%"
                }
//                adViewHolder.mStopButton.setText("下载中")
            }

            @SuppressLint("SetTextI18n")
            override fun onDownloadPaused(totalBytes: Long, currBytes: Long, fileName: String, appName: String) {
                if (!isValid) {
                    return
                }
                if (totalBytes <= 0L) {
                    adCreativeButton.text = "0%"
                } else {
                    adCreativeButton.text = (currBytes * 100 / totalBytes).toString() + "%"
                }
//                adViewHolder.mStopButton.setText("下载暂停")
            }

            override fun onDownloadFailed(totalBytes: Long, currBytes: Long, fileName: String, appName: String) {
                if (!isValid) {
                    return
                }
                adCreativeButton.text = "重新下载"
//                adViewHolder.mStopButton.setText("重新下载")
            }

            override fun onInstalled(fileName: String, appName: String) {
                if (!isValid) {
                    return
                }
                adCreativeButton.text = "点击打开"
//                adViewHolder.mStopButton.setText("点击打开")
            }

            override fun onDownloadFinished(totalBytes: Long, fileName: String, appName: String) {
                if (!isValid) {
                    return
                }
                adCreativeButton.text = "点击安装"
//                adViewHolder.mStopButton.setText("点击安装")
            }

            private val isValid: Boolean
                private get() = mTTAppDownloadListenerMap.get(adViewHolder) === this
        }
        //一个ViewHolder对应一个downloadListener, isValid判断当前ViewHolder绑定的listener是不是自己
        ad.setDownloadListener(downloadListener) // 注册下载监听器
        mTTAppDownloadListenerMap.put(adViewHolder, downloadListener)
    }

    private fun bindDownLoadStatusController(adViewHolder: CsjAdHolder, ad: TTFeedAd) {
        val controller = ad.downloadStatusController
//        adViewHolder.mStopButton.setOnClickListener(View.OnClickListener {
//            if (controller != null) {
//                controller.changeDownloadStatus()
//            }
//        })
//        adViewHolder.mRemoveButton.setOnClickListener(View.OnClickListener {
//            if (controller != null) {
//                controller.cancelDownload()
//            }
//        })
    }
}