package com.mints.goodmoney.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.mints.goodmoney.R
import com.mints.goodmoney.mvp.model.TzTaskBean
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener
import com.mints.library.utils.GlideUtils
import com.tz.sdk.core.ui.ADContainer
import java.lang.ref.WeakReference

class TaskAdapter(val dataList: List<TzTaskBean>, val context: Context) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private var mCurrentPosition = 0

    lateinit var mOnItemClickListener: OnItemClickListener
    lateinit var mOnItemChildClickListener: OnItemChildClickListener

    companion object {
        const val HOLDER_TYPE_SH_CPD = 0
        const val HOLDER_TYPE_CPD = 1
    }

    override fun getItemViewType(position: Int): Int {
        if (dataList[position].isShCpd) {
            return HOLDER_TYPE_SH_CPD
        }
        return HOLDER_TYPE_CPD
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        if (viewType == HOLDER_TYPE_SH_CPD) {
            // AdContainer 可能引起内存泄漏
            val weakReference = WeakReference<Context>(context)
            val view = LayoutInflater.from(weakReference.get()).inflate(R.layout.item_task_recy, parent, false)
            return SHViewHolder(view)
        }

        val view = LayoutInflater.from(context).inflate(R.layout.item_task_recy_cpd, parent, false)
        return CPDViewHolder(view)
    }

    override fun onBindViewHolder(viewHolder: RecyclerView.ViewHolder, position: Int) {
        val data = dataList[position]

        if (viewHolder is SHViewHolder) {
            viewHolder.adContainer.setAdModel(data.coralAd)
        }

        val holder = viewHolder as BaseViewHolder
        GlideUtils.loadImageView(context, data.icon, holder.ivAvatar)
        holder.tvTitle.text = data.title
        holder.tvCoin.text = "+" + data.coin + "金币"
        when (data.state) {
            0 -> {
                holder.btnSubmit.text = "立即下载"
            }
            1 -> {
                holder.btnSubmit.text = "去试玩"
            }
            2 -> {
                holder.btnSubmit.text = "立即领取"
            }
            3 -> {
                holder.btnSubmit.text = "已完成"
            }
            4 -> {
                holder.btnSubmit.text = "继续试玩"
            }
        }

        if (::mOnItemClickListener.isInitialized) {
            holder.itemView.setOnClickListener {
                setPosition(position)
                mOnItemClickListener.onItemClick(it, position)
            }
        }

        if (::mOnItemChildClickListener.isInitialized) {
            if (holder.btnSubmit.visibility == View.VISIBLE) {
                holder.btnSubmit.setOnClickListener {
                    setPosition(position)
                    mOnItemChildClickListener.onItemChildClick(it, position)
                }
            } else {
                holder.btnSubmit.setOnClickListener(null)
            }
        }
    }

    fun getPosition() = mCurrentPosition

    private fun setPosition(currentPosition: Int) {
        this.mCurrentPosition = currentPosition
        notifyDataSetChanged()
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

    fun setOnItemChildClickListener(listener: OnItemChildClickListener) {
        mOnItemChildClickListener = listener
    }

    override fun getItemCount() = dataList.size

    inner class SHViewHolder(view: View) : BaseViewHolder(view) {
        val adContainer: ADContainer = view.findViewById(R.id.ad_container)
    }

    inner class CPDViewHolder(view: View) : BaseViewHolder(view)

    open class BaseViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val ivAvatar: ImageView = view.findViewById(R.id.item_iv_avatar)
        val tvTitle: TextView = view.findViewById(R.id.item_tv_title)
        val tvCoin: TextView = view.findViewById(R.id.item_tv_coin)
        val btnSubmit: Button = view.findViewById(R.id.item_btn_submit)
    }
}