package com.mints.goodmoney.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.mints.goodmoney.R
import com.mints.goodmoney.utils.ToolUtil
import com.ximalaya.ting.android.opensdk.model.track.Track

class XmlyPlayAdapter(val xmlyPageList: MutableList<Track>, val xmlyUnlockList: List<String>) :
        RecyclerView.Adapter<XmlyPlayAdapter.ViewHolder>() {

    lateinit var context: Context

    lateinit var mOnItemClickListener: OnItemClickListener

    inner class ViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvIndex: TextView = view.findViewById(R.id.tv_index)
        val tvTitle: TextView = view.findViewById(R.id.tv_title)
        val tvCount: TextView = view.findViewById(R.id.tv_count)
        val ivIsLock: ImageView = view.findViewById(R.id.iv_islock)
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        context = parent.context
        val view = LayoutInflater.from(context).inflate(R.layout.item_rv_xmly_play, parent, false)
        return ViewHolder(view)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val track = xmlyPageList[position]
        holder.tvIndex.text = (position + 1).toString()
        holder.tvTitle.text = track.trackTitle
        holder.tvCount.text = ToolUtil.formatNum(track.playCount.toString(), false)
        holder.ivIsLock.setImageResource(R.mipmap.icon_lock)
        for (s in xmlyUnlockList) {
            if (position >= s.toInt() - 1) {
                if (s.toInt() - 1 == position) {
                    holder.ivIsLock.setImageResource(R.mipmap.icon_unlock)
                }
            }
        }

        holder.itemView.setOnClickListener {
            if (::mOnItemClickListener.isInitialized) {
                mOnItemClickListener.onItemClick(position)
            }
        }
    }

    override fun getItemCount() = xmlyPageList.size

    interface OnItemClickListener {
        fun onItemClick(position: Int)
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

}