package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.widget.FrameLayout
import android.widget.LinearLayout
import androidx.fragment.app.FragmentTransaction
import com.daimajia.androidanimations.library.Techniques
import com.daimajia.androidanimations.library.YoYo
import com.daimajia.androidanimations.library.YoYo.YoYoString
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.express.PreLoadExpressManager
import com.mints.goodmoney.ad.express.TTPreLoadExpressXmlyManager
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.*
import com.mints.goodmoney.mvp.model.MainVideoMsgBean
import com.mints.goodmoney.mvp.model.UserTaskMsgBean
import com.mints.goodmoney.mvp.presenters.HomePresenter
import com.mints.goodmoney.mvp.views.HomeView
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.ui.activitys.WebActivity
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.BindWxDialog
import com.mints.goodmoney.ui.widgets.DialogListener
import com.mints.goodmoney.ui.widgets.PowerDialog
import com.mints.goodmoney.ui.widgets.countdowntimer.CountDownTimerSupport
import com.mints.goodmoney.ui.widgets.countdowntimer.OnCountDownTimerListener
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.TimeRender
import com.mints.library.utils.CommonUtils
import com.yilan.sdk.player.ylplayer.YLPlayerConfig
import com.yilan.sdk.player.ylplayer.callback.OnPlayerCallBack
import com.yilan.sdk.ui.configs.YLUIConfig
import com.yilan.sdk.ui.little.YLLittleVideoFragment
import com.yilan.sdk.ylad.YLAdListener
import kotlinx.android.synthetic.main.layout_red_bag.*
import kotlinx.android.synthetic.main.layout_red_box.*
import net.grandcentrix.tray.AppPreferences

private val TAG = MainFragment::class.java.simpleName

/**
 * 描述：首页
 * 作者：孟崔广
 * 时间：2020/10/10 17:30
 */
class MainFragment : BaseFragment(), HomeView, View.OnClickListener {

    private val homePresenter by lazy { HomePresenter() }
    private val userManager by lazy { UserManager.getInstance() }
    private val ps by lazy { AppPreferences(context) }
    private var powerDialog: PowerDialog? = null
    private var bindWxDialog: BindWxDialog? = null

    private var userMsgBean: UserTaskMsgBean? = null

    // 视频相关
    private var rewardDoubleCoin = 0 // 大金币
    private var rewardCoin = 0 // 小金币
    private var littleVideoFragment: YLLittleVideoFragment? = null
    private val videoMaxCount = 12 // 当前缓存视频id最大数
    private val videoIdList by lazy { ArrayList<String>() }//记录播放的视频id

    private var isToCreateReward = true // 是否还有剩余红包 服务器返回
    private var isFirstLoadVideo = true // 首次加载视频初始化 本地判断
    private var isAward = false // 是否可以领金币 本地判断
    private var isFirstWatchVideo = true// 是否是第一次观看完视频

    // 广告权重相关
    private var videoAdingManager: VideoAdingManager? = null

    // 福袋相关
    private var rope: YoYoString? = null
    private var mRedBoxTimer: CountDownTimerSupport? = null
    private var mRedBoxCoin = 0
    private var mRedBoxCoinDouble = 0

    override fun getContentViewLayoutID() = R.layout.fragment_main_first

    override fun initViewsAndEvents() {
        homePresenter.attachView(this)

        videoAdingManager = VideoAdingManager.getInstance(activity)
        // 奖励页预加载 信息流广告
        PreLoadExpressManager.loadADFrameLayout()

        // 刷新喜马拉雅信息流
        TTPreLoadExpressXmlyManager.getInstance().loadTtFrameLayout()

        // 首次显示权限弹窗
        showPowerDialog()

        // 初始化视频
        showLittle()

        initListener()

        // 打开激活
        uploadDeviceInfo()

        // 每日任务是否刷新任务数
        innerApp()
    }

    private fun innerApp() {
        if (userManager.userIsLogin()) {
            homePresenter.getNetWorkIp()
            TrackManager.getInstance().innerApp()
        }
    }

    override fun onHiddenChanged(hidden: Boolean) {
        littleVideoFragment?.onHiddenChanged(hidden)

        if (hidden) {
            onPause()
        } else {
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()

        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_ONE) {
            if (!TextUtils.isEmpty(userManager?.userID)) {
                homePresenter.getHallBaseMsg()
            } else {
                homePresenter.userLogin()
            }

            if (isToCreateReward) {
                // 防止界面切换 重置红包动画
                // 好兔视频已加载 且 红包已转满
                if (!isFirstLoadVideo && !cdvvYilanTime.isPlaying) {
                    cdvvYilanTime.startAnim()
                }
            }

            registerPlayerCallBack()
            littleVideoFragment?.onResume()
        }
    }

    private fun uploadDeviceInfo() {
//        if (!ps.getBoolean(Constant.FIRST_DEVICE_FLAG, false)) {
        homePresenter.comSaveTerminalInfo(ps)
        baseApplication.initUm(context)
        baseApplication.TalkingDataConfig()
//        }
    }

    override fun onPause() {
        super.onPause()

        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_ONE) {
            YLPlayerConfig.config().unRegisterPlayerCallback()
        }
        // 福袋动画停止
        stopRedbox()
        // 倒计时红包暂停
        pauseDownloadTime()

        destoryTimerRedbox()
        littleVideoFragment?.onPause()

        if (isToCreateReward) {
            // 防止界面切换 重置红包动画
            // 好兔视频已加载 且 红包已转满
            if (!isFirstLoadVideo && !cdvvYilanTime.isPlaying) {
                cdvvYilanTime.stopAnim()
            }
        }
    }

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        littleVideoFragment?.userVisibleHint = isVisibleToUser
    }

    override fun onDestroyView() {
        if (rope != null) {
            rope?.stop()
            rope = null
        }

        cdvvYilanTime?.onDestroy()
        cdvvYilanTime?.setCountDownVideoListener(null)
        super.onDestroyView()
    }

    override fun onDestroy() {
        super.onDestroy()
        // 广告回调解绑
        YLUIConfig.getInstance().unRegisterAdListener()
        YLPlayerConfig.config().unRegisterPlayerCallback()

        homePresenter.detachView()
    }

    override fun getHallBaseMsgSuc(data: UserTaskMsgBean) {
        if (activity == null || requireActivity().isFinishing) {
            return
        }

        userMsgBean = data

        if (userMsgBean?.shareNews != null) {
            AppConfig.wzReadCoin = userMsgBean!!.shareNews.readCoin
        }

        // 保存Ip,用于穿山甲回调校验
        ps.put(Constant.CSJ_VEDIO_APPIP, data.ip)
        AppConfig.app_black_name = data.userRiskApps.userRiskAppName
        AppConfig.app_black_pkg = data.userRiskApps.userRiskAppPkg
        AppConfig.flVideoFlag = data.vedioRules.isFlVideoFlag
        AppConfig.user_register_channel = data.channel
        if (data.adcode != null) {
            AppConfig.user_channel_ad = data.adcode.key
        }
        ChannelManager.updataCodeIdForRegisterChannel(data.adcode)

        // 新人福利 放到个人中心展示 防止首页红包转动异常

        // 设置视频权重
        initAdWeight(data)

        // 调用金币视频信息接口
        homePresenter.getHomeVedioMsg()

        // 手机号登录未绑定微信 弹出界面不能关闭
        loginMobileBindWx()

        // 是否上报点击广告
        AppConfig.needReportClickAdEvent = data.isNeedReportClickAdEvent

        data.blessingBigMsgBean?.let {
            if (it.surplusCount > 0) {
                if (rl_fragment_main_redbox.visibility == View.GONE) {
                    rl_fragment_main_redbox.visibility = View.VISIBLE
                }
                mRedBoxCoin = it.coin
                mRedBoxCoinDouble = it.doubleCoin
                startTimer(it.surplusSeconds.toLong())
            } else {
                stopRedbox()
                rl_fragment_main_redbox.visibility = View.GONE
            }
        }
    }

    override fun getHomeVedioMsgSuc(data: MainVideoMsgBean) {
        if (activity == null || requireActivity().isFinishing) {
            return
        }

        ps.put(Constant.MAIN_VEDIO_TIME, data.createRewardNeedTime)

        rewardCoin = data.rewardCoin
        rewardDoubleCoin = data.rewardDoubleCoin
        isToCreateReward = data.isToCreateReward

        if (isToCreateReward) {
            // 防止界面切换 重置倒计时
            // 好兔视频已加载 且 红包已转满 且 奖励已领过
            if (!isFirstLoadVideo && !cdvvYilanTime.isPlaying && !isAward) {
                cdvvYilanTime?.stopRedbox()
                cdvvYilanTime?.reset()
                cdvvYilanTime?.start()
            }
        } else {
            cdvvYilanTime?.stopRedbox()
            stopDownloadTime()
        }
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.rl_fragment_main_redbox -> {
                val bundle = Bundle()
                bundle.putInt(Constant.MAIN_CUR_COIN, mRedBoxCoin)
                bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_BLESSINGBAG)
                bundle.putString(Constant.MAIN_EXTRA_ID, mRedBoxCoinDouble.toString())
                readyGo(AwardActivity::class.java, bundle)
            }
            R.id.cdvvYilanTime -> {
                // 视频已转满 且 服务返回可以领奖励
                if (isAward && isToCreateReward) {
                    isAward = false

                    val bundle = Bundle()
                    bundle.putInt(Constant.MAIN_CUR_COIN, rewardCoin)
                    bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_HOMEVEDIO)
                    bundle.putString(Constant.MAIN_EXTRA_ID, rewardDoubleCoin.toString())
                    readyGo(AwardActivity::class.java, bundle)
                }
            }
        }
    }

    private fun showPowerDialog() {
        if (ps.getBoolean(Constant.LOAN_PERMISSION_FLAG, true)) {
            powerDialog()
        } else {
            // 数美初始化
            ShumeiManager.getInstance().initShumei()
        }

        //闪电盒子传入oaid
        if (!TextUtils.isEmpty(MintsApplication.OAID)) {
            WnManager.setOaid(MintsApplication.OAID)
        }
    }

    /**
     * 一览视频初始化
     */
    private fun showLittle() {
        val transaction: FragmentTransaction = supportFragmentManager.beginTransaction()
        if (littleVideoFragment == null) {
            littleVideoFragment = YLLittleVideoFragment.newInstance()
            transaction.add(R.id.yilan_fragment_frame_container, littleVideoFragment!!, YLLittleVideoFragment::class.java.simpleName)
        } else {
            transaction.show(littleVideoFragment!!)
        }
        transaction.commitAllowingStateLoss()
    }

    private fun registerPlayerCallBack() {
        YLPlayerConfig.config().registerPlayerCallBack(object : OnPlayerCallBack {
            override fun onStart(pager: String, videoid: String, p2: String?) {
                // 防止网络异常时， 第一次加载倒计时红包
                if (isFirstLoadVideo) {
                    isFirstLoadVideo = false
                    initTimeview()
                } else {
                    resumeDownloadTime(videoid)
                }
            }

            override fun onPause(pager: String, p1: String?, p2: String?) {
                pauseDownloadTime()
            }

            override fun onResume(pager: String, videoid: String, p2: String?) {
                resumeDownloadTime(videoid)
            }

            override fun onComplete(pager: String, videoid: String, p2: String?) {

            }

            override fun onLoopComplete(pager: String?, videoID: String, taskID: String?, num: Int) {
//                LogUtil.d(TAG, "registerPlayerCallBack  onLoopComplete")
                addVideoIdList(videoID)
                pauseDownloadTime()
            }

            override fun onStuckStart(pager: String, p1: String?, p2: String?) {
            }

            override fun onStuckEnd(pager: String, p1: String?, p2: String?) {
            }

            override fun onError(pager: String, p1: String?, p2: String?) {

                pauseDownloadTime()
            }

            override fun onStop(pager: String, p1: String?, p2: String?) {
//                LogUtil.d(TAG, "registerPlayerCallBack  onStop")
//                pauseDownloadTime()
            }
        })
    }

    private fun initListener() {
        val params = LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT, LinearLayout.LayoutParams.WRAP_CONTENT)
        params.setMargins(0, 0, 0, BubbleUtils.dp2px(270))
        cdvvYilanTime.layoutParams = params

        val paramsRedBox = FrameLayout.LayoutParams(FrameLayout.LayoutParams.WRAP_CONTENT, FrameLayout.LayoutParams.WRAP_CONTENT)
        paramsRedBox.setMargins(0, BubbleUtils.dp2px(40), 0, 0)
        paramsRedBox.gravity = Gravity.END
        rl_fragment_main_redbox.layoutParams = paramsRedBox
        cdvvYilanTime.setOnClickListener(this)
        rl_fragment_main_redbox.setOnClickListener(this)
        rl_fragment_main_redbox.isClickable = false

        // 广告回调
        YLUIConfig.getInstance().registerAdListener(object : YLAdListener {
            override fun onSuccess(p0: String?, p1: Int, p2: String?, p3: String?) {
            }

            override fun onError(p0: String?, p1: Int, p2: String?, p3: Int, p4: String?, p5: String?) {
            }

            override fun onRenderError(p0: String?, p1: Int, p2: String?, p3: Int, p4: String?, p5: String?) {
            }

            override fun onShow(p0: String?, p1: Int, p2: String?, p3: String) {
                resumeAdTime()
            }

            override fun onClick(p0: String?, p1: Int, p2: String?, p3: String?) {}

            override fun onSkip(p0: String?, p1: Int, p2: String?, p3: String?) {}

            override fun onTimeOver(p0: String?, p1: Int, p2: String?, p3: String?) {}

            override fun onClose(p0: String?, p1: Int, p2: String?, p3: String?) {}

            override fun onAdEmpty(p0: String?, p1: Int, p2: String?, p3: String?) {}

            override fun onVideoStart(p0: String?, p1: Int, p2: String?, p3: String) {
            }

            override fun onVideoPause(p0: String?, p1: Int, p2: String?, p3: String?) {
                pauseDownloadTime()
            }

            override fun onVideoResume(p0: String?, p1: Int, p2: String?, p3: String?) {
                resumeAdTime()
            }

            override fun onVideoComplete(p0: String?, p1: Int, p2: String?, p3: String?) {
                pauseDownloadTime()
            }

            override fun onVideoError(p0: String?, p1: Int, p2: String?, p3: String?) {}

        })
    }

    private fun resumeAdTime() {
        // 视频未转满 且 界面切换时可继续加进度
        if (!isAward) {
            cdvvYilanTime?.resume()
        }
    }

    /**
     * 将播放的id记录到list中
     */
    private fun addVideoIdList(id: String) {
        // 达到12个视频时 删除前10个记录
        if (videoIdList.size >= videoMaxCount) {
            videoIdList.subList(0, 10).clear()
        }
        if (!videoIdList.contains(id)) videoIdList.add(id)
    }

    /**
     * 倒计时红包暂停
     */
    private fun pauseDownloadTime() {
        cdvvYilanTime?.pause()
    }

    /**
     *用户主动暂时或网络异常结束后 重新加载倒计时红包
     */
    private fun resumeDownloadTime(id: String) {
        if (!TextUtils.isEmpty(id)) {
            if (videoIdList.contains(id)) {
                cdvvYilanTime?.pause()
                return
            }

            // 视频未转满 且 界面切换时可继续加进度
            if (!isAward) {
                cdvvYilanTime?.resume()
            }
        }
    }

    /**
     * 停止转动
     */
    private fun stopDownloadTime() {
        cdvvYilanTime?.stop()
    }

    /**
     * 红包倒计时初始化
     */
    private fun initTimeview() {
        cdvvYilanTime?.setCountDownVideoListener {
            if (isFirstWatchVideo) {
                // 第一次观看完视频提醒用户
                vs_tips?.visibility = View.VISIBLE
                Handler(Looper.getMainLooper()).postDelayed({
                    vs_tips?.visibility = View.GONE
                }, 3000)
                isFirstWatchVideo = false
            }

            // 转满一圈，可领金币标记
            isAward = true
            cdvvYilanTime?.showRedbox()
            stopDownloadTime()
        }
        val videoTime = ps.getInt(Constant.MAIN_VEDIO_TIME, 30)
        cdvvYilanTime?.setTime(videoTime)
        cdvvYilanTime?.start()
    }

    /**
     * 权限弹窗
     */
    private fun powerDialog() {
        powerDialog = PowerDialog(requireActivity(), object : DialogListener() {
            override fun onClick(v: View) {
                when (v.id) {
                    R.id.tv_dialogper_agreement -> {
                        val bundle = Bundle()
                        bundle.putString(WebActivity.WEB_TITLE, getString(R.string.register_name))
                        bundle.putString(WebActivity.WEB_URL, Constant.REGISTER_URL)
                        readyGo(WebActivity::class.java, bundle)
                    }
                    R.id.tv_dialogper_policy -> {
                        val bundle = Bundle()
                        bundle.putString(WebActivity.WEB_TITLE, getString(R.string.privacy_name))
                        bundle.putString(WebActivity.WEB_URL, Constant.PRIVACY_URL)
                        readyGo(WebActivity::class.java, bundle)
                    }
                    R.id.btn_dialogper_back -> {
                        if (activity != null && !activity!!.isFinishing &&
                                powerDialog != null && powerDialog!!.isShowing
                        ) {
                            showToast("请您同意授权,否则将无法使用APP功能")
                        }
                    }
                    R.id.btn_dialogper_next -> {
                        if (activity != null && !activity!!.isFinishing &&
                                powerDialog != null && powerDialog!!.isShowing
                        ) {
                            powerDialog!!.dismiss()
                            ps.put(Constant.LOAN_PERMISSION_FLAG, false)

                            // 数美初始化
                            ShumeiManager.getInstance().initShumei()

                            // 游客首次提示1500新人奖励 且 不是分享包
                            val channel = CommonUtils.getAppMetaData(MintsApplication.getContext(), "CHANNEL_NAME")
                            if (!TextUtils.equals(channel, Constant.CHANNEL_SHARE) && ps.getBoolean(Constant.FIRST_VISITOR_FLAG, true)) {
                                ps.put(Constant.FIRST_VISITOR_FLAG, false)
                                val bundle = Bundle()
                                bundle.putInt(Constant.MAIN_CUR_COIN, if (userMsgBean != null && userMsgBean!!.userMsg.showCoin > 0) userMsgBean?.userMsg?.showCoin!! else 1500)
                                bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_NEW_VISITOR)
                                readyGo(AwardActivity::class.java, bundle)
                            }
                        }
                    }
                }
            }
        })
        powerDialog!!.show()
    }

    /**
     * 设置视频权重
     */
    private fun initAdWeight(data: UserTaskMsgBean) {
        videoAdingManager?.initAdWeight(data.vedioRules.csJ_VEDIO.rate,
                data.vedioRules.ylH_VEDIO.rate,
                data.vedioRules.sdhZ_VEDIO.rate,
                data.vedioRules.fL_VEDIO.rate,
                data.vedioRules.corAl_VIDEO.rate,
                data.vedioRules.csjfulL_VEDIO.rate)
        LogUtil.d(TAG, "首页权重值：csjWeight:${data.vedioRules.csJ_VEDIO.rate}    " +
                "ylhWeight:${data.vedioRules.ylH_VEDIO.rate}    " +
                "sdhzWeight:${data.vedioRules.sdhZ_VEDIO.rate}    " +
                "csjFullWeight:${data.vedioRules.csjfulL_VEDIO.rate}    " +
                "shWeight:${data.vedioRules.corAl_VIDEO.rate}    " +
                "flWeight:${data.vedioRules.fL_VEDIO.rate}")
        // 广告视频数
        AppConfig.csjVideoAdCount = data.vedioRules.csJ_VEDIO.surplus
        AppConfig.ylhAdCount = data.vedioRules.ylH_VEDIO.surplus
        AppConfig.wnVideoAdCount = data.vedioRules.sdhZ_VEDIO.surplus
        AppConfig.flVideoAdCount = data.vedioRules.fL_VEDIO.surplus
        AppConfig.csjFullVedioAdCount = data.vedioRules.csjfulL_VEDIO.surplus
        AppConfig.shVideoAdCount = data.vedioRules.corAl_VIDEO.surplus
        LogUtil.d(TAG, "首页视频数：csjCount:${AppConfig.csjVideoAdCount}    " +
                "ylhCount:${AppConfig.ylhAdCount}    " +
                "sdhzCount:${AppConfig.wnVideoAdCount}    " +
                "csjFullCount:${AppConfig.csjFullVedioAdCount}    " +
                "shCount:${AppConfig.shVideoAdCount}    " +
                "flCount:${AppConfig.flVideoAdCount}")
    }

    /**
     * 手机号登录未绑定微信 弹出界面不能关闭
     */
    private fun loginMobileBindWx() {
        if (userManager.userIsLogin() && TextUtils.isEmpty(userManager.wxOpenid)) {
            if (bindWxDialog == null) {
                bindWxDialog = BindWxDialog(requireActivity())
                bindWxDialog!!.show()
            }
        } else {
            if (bindWxDialog != null && bindWxDialog!!.isShowing) {
                bindWxDialog?.dismiss()
            }
        }
    }

    /**
     * 显示福袋动画
     */
    fun showRedbox(view: View?) {
        rope = null
        rope = YoYo.with(Techniques.Tada).duration(1000).repeat(-1).playOn(view)
    }

    /**
     * 暂停福袋动画
     */
    fun stopRedbox() {
        if (rope != null && rope!!.isRunning) {
            rope?.stop()
            rope = null
        }
    }

    /**
     * 开始福袋定时器
     */
    private fun startTimer(time: Long) {
        if (time > 0) {
            if (rl_fragment_main_redbox.visibility != View.VISIBLE) {
                rl_fragment_main_redbox.visibility = View.VISIBLE
            }
            stopRedbox()

            destoryTimerRedbox()
            mRedBoxTimer = CountDownTimerSupport(time * 1000, 1000)
            rl_fragment_main_redbox.isClickable = false

            mRedBoxTimer?.setOnCountDownTimerListener(object : OnCountDownTimerListener {
                override fun onTick(millisUntilFinished: Long) {
                    if (isAdded && !requireActivity().isFinishing) {
                        stopRedbox()
                        tv_fragment_main_redbox.text = TimeRender.ms2MS(millisUntilFinished.toInt())
                    }
                }

                override fun onFinish() {
                    if (isAdded && !requireActivity().isFinishing) {
                        tv_fragment_main_redbox.text = "可拆开"
                        rl_fragment_main_redbox.isClickable = true
                        showRedbox(rl_fragment_main_redbox)
                    }
                }
            })
            mRedBoxTimer?.start()
        } else {
            tv_fragment_main_redbox.text = "可拆开"
            rl_fragment_main_redbox.isClickable = true
            showRedbox(rl_fragment_main_redbox)
        }
    }

    private fun destoryTimerRedbox() {
        mRedBoxTimer?.stop()
        mRedBoxTimer = null
    }
}