package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import android.text.TextUtils
import android.webkit.WebChromeClient
import com.component.dly.xzzq_ywsdk.YwSDK_WebActivity
import com.github.lzyzsd.jsbridge.CallBackFunction
import com.github.lzyzsd.jsbridge.DefaultHandler
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.manager.YwhzManager
import com.mints.goodmoney.mvp.model.PanActionInfo
import com.mints.goodmoney.mvp.model.TurntableBean
import com.mints.goodmoney.mvp.presenters.PanPresenter
import com.mints.goodmoney.mvp.views.PanView
import com.mints.goodmoney.ui.activitys.*
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.library.utils.json.JsonUtil
import com.xiangzi.articlesdk.callback.IXzArticleSdkInitCallback
import com.xiangzi.articlesdk.core.XzArticleCoreImpl
import com.xiangzi.articlesdk.exception.XzSdkException
import kotlinx.android.synthetic.main.fragment_main_pan.*

/**
 * 描述：大转盘
 * 作者：孟崔广
 * 时间：2020/9/20 17:30
 */
class PanFragment : BaseFragment(), PanView {

    private val panPresenter by lazy { PanPresenter() }
    private val userManager by lazy { UserManager.getInstance() }
    private val carrierType = Constant.CARRIER_CHALLENGE_TURN

    override fun getContentViewLayoutID() = R.layout.fragment_main_pan

    override fun initViewsAndEvents() {
        panPresenter.attachView(this)

        if (!TextUtils.isEmpty(userManager.userID)) {
            // 登录成功的用户初始化鱼丸盒子
            if (userManager.userIsLogin()) {
                YwhzManager.init(baseApplication)
            }
        }
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_THREE) {
            if (TextUtils.isEmpty(userManager?.userID)) {
                // 游客登录
                panPresenter.userLogin()
            } else {
                loadTurnUrl()
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        panPresenter.detachView()
    }

    override fun loginSuc() {
        loadTurnUrl()
    }

    /**
     * 加载转盘url
     */
    private fun loadTurnUrl() {
        getTurnUrl()
//        blTurntableWebview.setOnTouchListener { _, event -> event.action == MotionEvent.ACTION_MOVE }
        blTurntableWebview.setDefaultHandler(DefaultHandler())
        blTurntableWebview.webChromeClient = WebChromeClient()
//        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
//            blTurntableWebview.setOnScrollChangeListener(
//                    object : View.OnScrollChangeListener {
//                        override fun onScrollChange(v: View?, scrollX: Int, scrollY: Int, oldScrollX: Int, oldScrollY: Int) {
//                            blTurntableWebview.scrollTo(0,scrollY)
//                        }
//                    })
//        }
        blTurntableWebview.setOnLongClickListener { true }
        //注册监听方法当js中调用callHandler方法时会调用此方法（handlerName必须和js中相同）
        blTurntableWebview.registerHandler("getTurnResult") { data, _ ->
            val turntableBean: TurntableBean = JsonUtil.parseJson(data, TurntableBean::class.java)
            val bundle = Bundle()
            bundle.putInt(Constant.MAIN_CUR_COIN, turntableBean.coin)
            bundle.putString(Constant.MAIN_CARRIER_TYPE, carrierType)
            bundle.putString(Constant.MAIN_EXTRA_ID, turntableBean.key)
            readyGo(AwardActivity::class.java, bundle)

            androidCallJsReferse()
        }
        blTurntableWebview.registerHandler("actionPageForType") { data, _ ->
            actionPageForType(data)
        }
        blTurntableWebview.setDefaultHandler(object : DefaultHandler() {
            override fun handler(data: String, function: CallBackFunction) {
                showToast(data)
            }
        })
    }

    private fun actionPageForType(data: String?) {
        if (TextUtils.isEmpty(data)) return
        val panActionInfo: PanActionInfo = JsonUtil.parseJson(data, PanActionInfo::class.java)
        //0-微转，1-珊瑚下载，2-分红，3-鱼丸盒子，4-每日任务
        when (panActionInfo.actionType) {
            0 -> {
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                shareArticle(panActionInfo.coin)
            }
            1 -> {
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                val bundle = Bundle()
                bundle.putInt(TaskActivity.TASK_COIN, panActionInfo.coin)
                readyGo(TaskActivity::class.java, bundle)
            }
            2 -> {
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                val bundle = Bundle()
                bundle.putInt(Constant.WRAPPER_TYPE, Constant.WRAPPER_TYPE_FRIENDS)
                readyGo(WrapperActivity::class.java, bundle)
            }
            3 -> {
                if (!userManager.userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                try {
                    activity?.let { YwSDK_WebActivity.open(it) }
                } catch (e: Exception) {
                    e.printStackTrace()
                    showToast("请重新退出账号登录")
                }
            }
            4 -> {
                val activity: MainActivity? = activity as MainActivity?
                activity?.let {
                    it.turnDayTask()
                }
            }
        }

    }

    /**
     * 获取转盘url
     */
    private fun getTurnUrl() {
        val tokenID = userManager.tokenID
        val url: String = BuildConfig.MainIp + "turn/turnWithInner.html?carrierType=" + carrierType + "&token=" + tokenID
        blTurntableWebview.loadUrl(url)
    }

    /**
     * 奖励成功刷新js界面
     */
    private fun androidCallJsReferse() {
        // 调用js中的方法（必须和js中的handlerName想同）
        blTurntableWebview.callHandler("refreshTurnTable", "") {
        }
    }

    /**
     * 分享文章
     */
    private fun shareArticle(coin: Int) {
        if (XzArticleCoreImpl.get().initIsSuccess()) {
            XzArticleCoreImpl.get().openArticleListActivity(requireActivity())
        } else {
            try {
                XzArticleCoreImpl.get().initUser(userManager.userID, coin.toString(), "金币",
                        object : IXzArticleSdkInitCallback {
                            override fun initSuccess() {
                                shareArticle(coin)
                            }

                            override fun initFailed(errMsg: String) {
                                showToast("初始化失败，请稍候重试~")
                            }
                        })
            } catch (e: XzSdkException) {
                e.printStackTrace()
            }
        }
    }
}