package com.mints.goodmoney.ui.fragment

import android.annotation.SuppressLint
import android.text.TextUtils
import android.webkit.*
import cn.sharesdk.framework.Platform
import cn.sharesdk.framework.PlatformActionListener
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import cn.sharesdk.wechat.moments.WechatMoments
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.views.BaseView
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.utils.ToastUtil
import kotlinx.android.synthetic.main.fragment_main_wz.*
import java.lang.StringBuilder
import java.util.HashMap

/**
 * 描述：微转分享
 * 作者：孟崔广
 * 时间：2020/9/20 17:30
 */
@SuppressLint("SetJavaScriptEnabled")
class WzFragment : BaseFragment(), BaseView {

    private val userManager by lazy { UserManager.getInstance() }

    override fun getContentViewLayoutID() = R.layout.fragment_main_wz

    override fun initViewsAndEvents() {

    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FOUR) {
            if (TextUtils.isEmpty(userManager?.userID)) {
                // 游客登录

            } else {
                loadWzUrl()
            }
        }
    }

    /**
     * 加载微转url
     */
    private fun loadWzUrl() {
        getWzUrl()

        blTurntableWebview.webChromeClient = WebChromeClient()
        blTurntableWebview.webViewClient = object : WebViewClient() {}

        blTurntableWebview.addJavascriptInterface(object : JsObject() {}, "mobile")
        val settings = blTurntableWebview.settings
        settings.javaScriptEnabled = true
    }

    /**
     * 获取微转url
     */
    private fun getWzUrl() {
        val sb = StringBuilder()
        sb.append("http://api.wenlv-kd.com/h5/init.html?appkey=haozhuanqian&appid=169")
                .append("&userid=" + userManager.userID)
                .append("&reward=" + AppConfig.wzReadCoin)
                .append("&unit=" + "金币")
        blTurntableWebview.loadUrl(sb.toString())
    }

    open class JsObject {

        /**
         * 分享文章
         */
        @JavascriptInterface
        fun shareArticle(shareImageUrl: String, shareTarget: String, shareTitle: String, shareUrl: String, shareContent: String) {
            val wechatSp = Platform.ShareParams()
            wechatSp.shareType = Platform.SHARE_WEBPAGE
            wechatSp.imageUrl = shareImageUrl
            wechatSp.title = shareTitle
            wechatSp.url = shareUrl
            wechatSp.text = shareContent

            val wechatTarget: Platform = when (shareTarget) {
                "timegroup" -> {
                    ShareSDK.getPlatform(Wechat.NAME)
                }
                "timeline" -> {
                    ShareSDK.getPlatform(WechatMoments.NAME)
                }
                else -> {
                    ShareSDK.getPlatform(Wechat.NAME)
                }
            }

            if (wechatTarget.isClientValid) {
                wechatTarget.platformActionListener = object : PlatformActionListener {
                    override fun onComplete(p0: Platform?, p1: Int, p2: HashMap<String, Any>?) {
                    }

                    override fun onError(p0: Platform?, p1: Int, p2: Throwable?) {
                    }

                    override fun onCancel(p0: Platform?, p1: Int) {
                    }
                }
                wechatTarget.share(wechatSp)
            } else {
                ToastUtil.show(MintsApplication.getContext(), "请先安装微信")
            }
        }
    }
}