package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import androidx.recyclerview.widget.GridLayoutManager
import com.mints.goodmoney.R
import com.mints.goodmoney.ui.activitys.XmlyPlayActivity
import com.mints.goodmoney.ui.adapter.XmlyPageAdapter
import com.mints.goodmoney.ui.fragment.base.LazyLoadBaseFragment
import com.mints.goodmoney.utils.LogUtil
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadMoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import com.ximalaya.ting.android.opensdk.constants.DTransferConstants
import com.ximalaya.ting.android.opensdk.datatrasfer.CommonRequest
import com.ximalaya.ting.android.opensdk.datatrasfer.IDataCallBack
import com.ximalaya.ting.android.opensdk.model.album.Album
import com.ximalaya.ting.android.opensdk.model.album.AlbumList
import kotlinx.android.synthetic.main.fragment_main_xmly_page.*

/**
 * 描述：喜马拉雅封面
 * 作者：孟崔广
 */
class XmlyPageFragment(private val categoryId: Long) : LazyLoadBaseFragment(),
        XmlyPageAdapter.OnItemClickListener,
        OnRefreshListener,
        OnLoadMoreListener {

    private lateinit var xmlyPageAdapter: XmlyPageAdapter
    private var xmlyData: MutableList<Album> = mutableListOf()

    // 分页
    private var xmlyPage = 1
    private val PAGE_SIZE = 10

    override fun getContentViewLayoutID() = R.layout.fragment_main_xmly_page

    override fun initViewsAndEvents() {
    }

    private fun loadData() {
        val vo = hashMapOf<String, String>()
        // 专辑id
        vo[DTransferConstants.CATEGORY_ID] = categoryId.toString()
        // 1-最火 2-最新 3-最多播放
        vo[DTransferConstants.CALC_DIMENSION] = "1"
        vo[DTransferConstants.PAGE] = xmlyPage.toString()
        vo[DTransferConstants.PAGE_SIZE] = PAGE_SIZE.toString()
        CommonRequest.getAlbumList(vo, object : IDataCallBack<AlbumList> {
            override fun onSuccess(p0: AlbumList?) {
                if (p0 != null && p0.albums != null && p0.albums.size != 0) {
                    activity?.runOnUiThread {
                        getDataSuc(p0.albums)
                    }

                } else {
                    getDataFail()
                }
            }

            override fun onError(p0: Int, p1: String?) {
                LogUtil.e(p1)
                getDataFail()
            }

        })
    }

    override fun onFragmentFirstVisible() {
        super.onFragmentFirstVisible()

        initRvView()
        loadData()
        initListener()
    }

    override fun onItemClick(position: Int) {
        val bundle = Bundle()
        bundle.putLong(XmlyPlayActivity.ALBUM_ID, xmlyData[position].id)
        bundle.putLong(XmlyPlayActivity.CATEGORY_ID, categoryId)
        readyGo(XmlyPlayActivity::class.java, bundle)
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        xmlyPage = 1
        xmlyData.clear()
        srl_xmly.resetNoMoreData()
        loadData()
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        xmlyPage = ++xmlyPage
        loadData()
    }

    private fun initRvView() {
        val gridLayoutManager = GridLayoutManager(context, 2)
        xmlyPageVip.layoutManager = gridLayoutManager
        xmlyPageAdapter = XmlyPageAdapter(xmlyData)
        xmlyPageVip.adapter = xmlyPageAdapter
        xmlyPageAdapter.setOnItemClickListener(this)
    }

    private fun initListener() {
        srl_xmly.setOnRefreshListener(this)
        srl_xmly.setOnLoadMoreListener(this)
    }

    /**
     * 获取数据失败
     */
    private fun getDataFail() {
        srl_xmly.finishRefresh(false)
        srl_xmly.finishLoadMore(false)
        xmlyPage = if (xmlyPage == 1) 1 else xmlyPage - 1
    }

    /**
     * 获取数据成功
     */
    private fun getDataSuc(list: List<Album>) {
        if (::xmlyPageAdapter.isInitialized) {
            xmlyData.addAll(list)
            if (xmlyPage == 1) {
                srl_xmly.finishRefresh(true)
                xmlyPageAdapter.notifyDataSetChanged()
            } else {
                if (list.size < PAGE_SIZE) {
                    srl_xmly.finishLoadMoreWithNoMoreData()
                } else {
                    srl_xmly.finishLoadMore()
                }
                xmlyPageAdapter.notifyItemChanged(list.size)
            }
        }
    }
}