package com.mints.goodmoney.ui.widgets

import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.os.Bundle
import android.view.Gravity
import android.view.KeyEvent
import android.view.View
import android.view.WindowManager
import android.widget.TextView
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.login.LoginApi
import com.mints.goodmoney.login.OnLoginListener
import com.mints.goodmoney.mvp.model.DrawcashBean
import com.mints.goodmoney.mvp.model.WXInfo
import com.mints.goodmoney.mvp.presenters.SettingsPresenter
import com.mints.goodmoney.mvp.views.SettingsView
import com.mints.goodmoney.ui.activitys.AccountMergeActivity
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.utils.ToastUtil
import com.mints.library.utils.json.JsonUtil
import com.mints.library.utils.nodoubleclick.AntiShake
import java.util.*

/**
 * 微信授权弹窗
 */
class BindWxDialog(context: Activity) :
        Dialog(context, R.style.dialog), OnLoginListener, SettingsView, View.OnClickListener {

    private var loginApi: LoginApi? = null
    private var settingsPresenter: SettingsPresenter? = null
    private var wxInfo: WXInfo? = null

    init {
        setContentView(R.layout.dialog_bindwx)
        // 设置window属性
        val lp = window!!.attributes
        lp.gravity = Gravity.CENTER
        lp.width = WindowManager.LayoutParams.MATCH_PARENT
        lp.windowAnimations = R.style.DialogAnimBottom
        window!!.attributes = lp

        // 设置外部不可关闭
        setCancelable(false)
        setCanceledOnTouchOutside(false)
        setOnKeyListener { _, i, _ ->
            i == KeyEvent.KEYCODE_BACK
        }

        findViewById<View>(R.id.btn_dialogper_next).setOnClickListener(this)

        loginApi = LoginApi()
        settingsPresenter = SettingsPresenter()
        settingsPresenter?.attachView(this)
    }

    override fun dismiss() {
        super.dismiss()
        loginApi?.setOnLoginListener(null)
        settingsPresenter?.detachView()
    }

    override fun onClick(v: View) {
        if (AntiShake.check(v?.id)) return
        when (v.id) {
            R.id.btn_dialogper_next -> {
                val wechat = ShareSDK.getPlatform(Wechat.NAME)
                if (!wechat.isClientValid) {
                    showToast("请先安装微信")
                    return
                }

                loginApi?.let {
                    it.setOnLoginListener(this)
                    it.setPlatform(Wechat.NAME)
                    it.login(context)
                }

            }
        }
    }

    override fun onLogin(platform: String?, res: HashMap<String, Any>): Boolean {
        try {
            wxInfo = WXInfo()
            wxInfo?.let {
                it.setUnionid(res["unionid"].toString() + "")
                it.setOpenid(res["openid"].toString() + "")
                it.setProvince(res["province"].toString() + "")
                it.setCity(res["city"].toString() + "")
                it.setCountry(res["country"].toString() + "")
                it.setHeadimgurl(res["headimgurl"].toString() + "")
                it.setNickname(res["nickname"].toString() + "")
                it.setSex((res["sex"].toString() + "").toInt())
            }

            settingsPresenter?.editUserMsg(res["openid"].toString(), JsonUtil.toJson(wxInfo))
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return false
    }

    override fun mergeAccount(mobile: String, wxOpenId: String, key: String) {
        val bundle = Bundle()
        bundle.putString(Constant.MERGE_MOBILE, mobile)
        bundle.putString(Constant.MERGE_WXOPENID, wxOpenId)
        bundle.putString(Constant.MERGE_KEY, key)
        readyGo(AccountMergeActivity::class.java, bundle)
    }

    protected fun readyGo(clazz: Class<*>?, bundle: Bundle?) {
        val intent = Intent(context, clazz)
        if (null != bundle) {
            intent.putExtras(bundle)
        }
        context.startActivity(intent)
    }

    override fun editUserMsgSuc() {
        ToastUtil.show(context, "微信绑定成功")
        dismiss()
    }

    override fun getUserTaskMsgSuc(data: DrawcashBean) {

    }

    override fun showLoading(msg: String?) {

    }

    override fun showToast(msg: String?) {
        ToastUtil.showLong(context, msg)
    }

    override fun hideLoading() {

    }

    override fun getBaseApplication(): MintsApplication {
        return MintsApplication.getContext() as MintsApplication
    }
}