/**
 * ToolUtil.java
 * com.chad.android.library.util
 * <p/>
 * <p/>
 * ver     date      		author
 * ---------------------------------------
 * 2015-4-9 		chadwii
 * <p/>
 * Copyright (c) 2015, chadwii All Rights Reserved.
 */

package com.mints.goodmoney.utils;

import android.content.Context;
import android.text.TextUtils;

import com.ximalaya.ting.android.opensdk.constants.ConstantsOpenSdk;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

/**
 * ClassName:ToolUtil
 *
 * @author chadwii
 * @Date 2015-4-9  5:17:32
 * @see
 * @since Ver 1.1
 */
public class ToolUtil {
    /**
     * one hour in ms
     */
    private static final int ONE_HOUR = 1 * 60 * 60 * 1000;
    /**
     * one minute in ms
     */
    private static final int ONE_MIN = 1 * 60 * 1000;
    /**
     * one second in ms
     */
    private static final int ONE_SECOND = 1 * 1000;

    private static int sScreenWidth;
    private static int sScreenHeight;
    private static float sDensity;

    public static int dp2px(Context ctx, int dp) {
        if (sDensity == 0) {
            sDensity = ctx.getResources().getDisplayMetrics().density;
        }
        return (int) (dp * sDensity + 0.5f);
    }

    public static int px2dp(Context ctx, int px) {
        if (sDensity == 0) {
            sDensity = ctx.getResources().getDisplayMetrics().density;
        }
        return (int) (px / sDensity + 0.5f);
    }

    public static int getScreenWidth(Context ctx) {
        if (sScreenWidth == 0) {
            sScreenWidth = ctx.getResources().getDisplayMetrics().widthPixels;
        }
        return sScreenWidth;
    }

    public static int getScreenHeight(Context ctx) {
        if (sScreenHeight == 0) {
            sScreenHeight = ctx.getResources().getDisplayMetrics().heightPixels;
        }
        return sScreenHeight;
    }

    /**
     * HH:mm:ss
     */
    public static String formatTime(long ms) {
        StringBuilder sb = new StringBuilder();
        int hour = (int) (ms / ONE_HOUR);
        int min = (int) ((ms % ONE_HOUR) / ONE_MIN);
        int sec = (int) (ms % ONE_MIN) / ONE_SECOND;
        if (hour == 0) {
//			sb.append("00:");
        } else if (hour < 10) {
            sb.append("0").append(hour).append(":");
        } else {
            sb.append(hour).append(":");
        }
        if (min == 0) {
            sb.append("00:");
        } else if (min < 10) {
            sb.append("0").append(min).append(":");
        } else {
            sb.append(min).append(":");
        }
        if (sec == 0) {
            sb.append("00");
        } else if (sec < 10) {
            sb.append("0").append(sec);
        } else {
            sb.append(sec);
        }
        return sb.toString();
    }

    public static boolean isEmpty(String str) {
        if (str == null || str.trim().equals("") || str.trim().equals("null")) {
            return true;
        }
        return false;
    }

    public static int isInTime(String time) throws IllegalArgumentException {
        if (TextUtils.isEmpty(time) || !time.contains("-")
                || !time.contains(":")) {
            if (ConstantsOpenSdk.isDebug) {
                throw new IllegalArgumentException("Illegal Argument arg:" + time);
            } else {
                return -2;
            }
        }
        String[] args = time.split("-");
        boolean onlyHasHour = (args[0].split(":")).length == 2;
        boolean hasDay = (args[0].split(":")).length == 3;
        boolean hasYear = (args[0].split(":")).length == 5;
        SimpleDateFormat sdf = null;
        if (hasDay) {
            sdf = new SimpleDateFormat("dd:HH:mm", Locale.getDefault());
        } else if (hasYear) {
            sdf = new SimpleDateFormat("yy:MM:dd:HH:mm", Locale.getDefault());
        } else if (onlyHasHour) {
            sdf = new SimpleDateFormat("HH:mm", Locale.getDefault());
        }
        if (sdf != null) {
            String nowStr = sdf.format(new Date(System.currentTimeMillis()));
            try {
                long now = sdf.parse(nowStr).getTime();
                long start = sdf.parse(args[0]).getTime();
                if (args[1].contains("00:00") && hasDay) {
                    args[1] = (args[1].split(":"))[0] + ":" + "23:59";
                } else if (args[1].contains("00:00") && hasYear) {
                    args[1] = (args[1].split(":"))[0] + ":"
                            + (args[1].split(":"))[1] + ":"
                            + (args[1].split(":"))[2] + ":" + "23:59";
                } else if (args[1].contains("00:00") && onlyHasHour) {
                    args[1] = "23:59";
                }
                long end = sdf.parse(args[1]).getTime();
                if (now >= end) {
                    return -1;
                } else if (now >= start && now < end) {
                    return 0;
                } else {
                    return 1;
                }
            } catch (ParseException e) {
                e.printStackTrace();
                if (ConstantsOpenSdk.isDebug) {
                    throw new IllegalArgumentException("Illegal Argument arg:"
                            + time);
                } else {
                    return -2;
                }
            }
        }
        return -2;
    }

    public static float formatNumCNY(int num) {
        return ((float) num) / 10000f;
    }

    /**
     * <pre>
     * 数字格式化显示
     * 小于万默认显示 大于万以1.7万方式显示最大是9999.9万
     * 大于亿以1.1亿方式显示最大没有限制都是亿单位
     * make by dongxh 2017年12月28日上午10:05:22
     * </pre>
     *
     * @param num   格式化的数字
     * @param kBool 是否格式化千,为true,并且num大于999就显示999+,小于等于999就正常显示
     * @return
     */
    public static String formatNum(String num, Boolean kBool) {
        StringBuffer sb = new StringBuffer();
        if (num == null)
            return "0";
        if (kBool == null)
            kBool = false;

        BigDecimal b0 = new BigDecimal("1000");
        BigDecimal b1 = new BigDecimal("10000");
        BigDecimal b2 = new BigDecimal("100000000");
        BigDecimal b3 = new BigDecimal(num);

        String formatNumStr = "";
        String nuit = "";

        // 以千为单位处理
        if (kBool) {
            if (b3.compareTo(b0) == 0 || b3.compareTo(b0) == 1) {
                return "999+";
            }
            return num;
        }

        // 以万为单位处理
        if (b3.compareTo(b1) == -1) {
            sb.append(b3.toString());
        } else if ((b3.compareTo(b1) == 0 && b3.compareTo(b1) == 1)
                || b3.compareTo(b2) == -1) {
            formatNumStr = b3.divide(b1).toString();
            nuit = "万";
        } else if (b3.compareTo(b2) == 0 || b3.compareTo(b2) == 1) {
            formatNumStr = b3.divide(b2).toString();
            nuit = "亿";
        }
        if (!"".equals(formatNumStr)) {
            int i = formatNumStr.indexOf(".");
            if (i == -1) {
                sb.append(formatNumStr).append(nuit);
            } else {
                i = i + 1;
                String v = formatNumStr.substring(i, i + 1);
                if (!v.equals("0")) {
                    sb.append(formatNumStr.substring(0, i + 1)).append(nuit);
                } else {
                    sb.append(formatNumStr.substring(0, i - 1)).append(nuit);
                }
            }
        }
        if (sb.length() == 0)
            return "0";
        return sb.toString();
    }

}

